(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory(require("react"));
	else if(typeof define === 'function' && define.amd)
		define(["react"], factory);
	else if(typeof exports === 'object')
		exports["ReactJsonTree"] = factory(require("react"));
	else
		root["ReactJsonTree"] = factory(root["React"]);
})(window, function(__WEBPACK_EXTERNAL_MODULE_react__) {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, { enumerable: true, get: getter });
/******/ 		}
/******/ 	};
/******/
/******/ 	// define __esModule on exports
/******/ 	__webpack_require__.r = function(exports) {
/******/ 		if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 			Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 		}
/******/ 		Object.defineProperty(exports, '__esModule', { value: true });
/******/ 	};
/******/
/******/ 	// create a fake namespace object
/******/ 	// mode & 1: value is a module id, require it
/******/ 	// mode & 2: merge all properties of value into the ns
/******/ 	// mode & 4: return value when already ns object
/******/ 	// mode & 8|1: behave like require
/******/ 	__webpack_require__.t = function(value, mode) {
/******/ 		if(mode & 1) value = __webpack_require__(value);
/******/ 		if(mode & 8) return value;
/******/ 		if((mode & 4) && typeof value === 'object' && value && value.__esModule) return value;
/******/ 		var ns = Object.create(null);
/******/ 		__webpack_require__.r(ns);
/******/ 		Object.defineProperty(ns, 'default', { enumerable: true, value: value });
/******/ 		if(mode & 2 && typeof value != 'string') for(var key in value) __webpack_require__.d(ns, key, function(key) { return value[key]; }.bind(null, key));
/******/ 		return ns;
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = 0);
/******/ })
/************************************************************************/
/******/ ({

/***/ "../../node_modules/base16/lib/apathy.js":
/*!**********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/apathy.js ***!
  \**********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'apathy',\n  author: 'jannik siebert (https://github.com/janniks)',\n  base00: '#031A16',\n  base01: '#0B342D',\n  base02: '#184E45',\n  base03: '#2B685E',\n  base04: '#5F9C92',\n  base05: '#81B5AC',\n  base06: '#A7CEC8',\n  base07: '#D2E7E4',\n  base08: '#3E9688',\n  base09: '#3E7996',\n  base0A: '#3E4C96',\n  base0B: '#883E96',\n  base0C: '#963E4C',\n  base0D: '#96883E',\n  base0E: '#4C963E',\n  base0F: '#3E965B'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/apathy.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/ashes.js":
/*!*********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/ashes.js ***!
  \*********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'ashes',\n  author: 'jannik siebert (https://github.com/janniks)',\n  base00: '#1C2023',\n  base01: '#393F45',\n  base02: '#565E65',\n  base03: '#747C84',\n  base04: '#ADB3BA',\n  base05: '#C7CCD1',\n  base06: '#DFE2E5',\n  base07: '#F3F4F5',\n  base08: '#C7AE95',\n  base09: '#C7C795',\n  base0A: '#AEC795',\n  base0B: '#95C7AE',\n  base0C: '#95AEC7',\n  base0D: '#AE95C7',\n  base0E: '#C795AE',\n  base0F: '#C79595'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/ashes.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/atelier-dune.js":
/*!****************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/atelier-dune.js ***!
  \****************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'atelier dune',\n  author: 'bram de haan (http://atelierbram.github.io/syntax-highlighting/atelier-schemes/dune)',\n  base00: '#20201d',\n  base01: '#292824',\n  base02: '#6e6b5e',\n  base03: '#7d7a68',\n  base04: '#999580',\n  base05: '#a6a28c',\n  base06: '#e8e4cf',\n  base07: '#fefbec',\n  base08: '#d73737',\n  base09: '#b65611',\n  base0A: '#cfb017',\n  base0B: '#60ac39',\n  base0C: '#1fad83',\n  base0D: '#6684e1',\n  base0E: '#b854d4',\n  base0F: '#d43552'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/atelier-dune.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/atelier-forest.js":
/*!******************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/atelier-forest.js ***!
  \******************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'atelier forest',\n  author: 'bram de haan (http://atelierbram.github.io/syntax-highlighting/atelier-schemes/forest)',\n  base00: '#1b1918',\n  base01: '#2c2421',\n  base02: '#68615e',\n  base03: '#766e6b',\n  base04: '#9c9491',\n  base05: '#a8a19f',\n  base06: '#e6e2e0',\n  base07: '#f1efee',\n  base08: '#f22c40',\n  base09: '#df5320',\n  base0A: '#d5911a',\n  base0B: '#5ab738',\n  base0C: '#00ad9c',\n  base0D: '#407ee7',\n  base0E: '#6666ea',\n  base0F: '#c33ff3'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/atelier-forest.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/atelier-heath.js":
/*!*****************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/atelier-heath.js ***!
  \*****************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'atelier heath',\n  author: 'bram de haan (http://atelierbram.github.io/syntax-highlighting/atelier-schemes/heath)',\n  base00: '#1b181b',\n  base01: '#292329',\n  base02: '#695d69',\n  base03: '#776977',\n  base04: '#9e8f9e',\n  base05: '#ab9bab',\n  base06: '#d8cad8',\n  base07: '#f7f3f7',\n  base08: '#ca402b',\n  base09: '#a65926',\n  base0A: '#bb8a35',\n  base0B: '#379a37',\n  base0C: '#159393',\n  base0D: '#516aec',\n  base0E: '#7b59c0',\n  base0F: '#cc33cc'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/atelier-heath.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/atelier-lakeside.js":
/*!********************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/atelier-lakeside.js ***!
  \********************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'atelier lakeside',\n  author: 'bram de haan (http://atelierbram.github.io/syntax-highlighting/atelier-schemes/lakeside/)',\n  base00: '#161b1d',\n  base01: '#1f292e',\n  base02: '#516d7b',\n  base03: '#5a7b8c',\n  base04: '#7195a8',\n  base05: '#7ea2b4',\n  base06: '#c1e4f6',\n  base07: '#ebf8ff',\n  base08: '#d22d72',\n  base09: '#935c25',\n  base0A: '#8a8a0f',\n  base0B: '#568c3b',\n  base0C: '#2d8f6f',\n  base0D: '#257fad',\n  base0E: '#5d5db1',\n  base0F: '#b72dd2'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/atelier-lakeside.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/atelier-seaside.js":
/*!*******************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/atelier-seaside.js ***!
  \*******************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'atelier seaside',\n  author: 'bram de haan (http://atelierbram.github.io/syntax-highlighting/atelier-schemes/seaside/)',\n  base00: '#131513',\n  base01: '#242924',\n  base02: '#5e6e5e',\n  base03: '#687d68',\n  base04: '#809980',\n  base05: '#8ca68c',\n  base06: '#cfe8cf',\n  base07: '#f0fff0',\n  base08: '#e6193c',\n  base09: '#87711d',\n  base0A: '#c3c322',\n  base0B: '#29a329',\n  base0C: '#1999b3',\n  base0D: '#3d62f5',\n  base0E: '#ad2bee',\n  base0F: '#e619c3'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/atelier-seaside.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/bespin.js":
/*!**********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/bespin.js ***!
  \**********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'bespin',\n  author: 'jan t. sott',\n  base00: '#28211c',\n  base01: '#36312e',\n  base02: '#5e5d5c',\n  base03: '#666666',\n  base04: '#797977',\n  base05: '#8a8986',\n  base06: '#9d9b97',\n  base07: '#baae9e',\n  base08: '#cf6a4c',\n  base09: '#cf7d34',\n  base0A: '#f9ee98',\n  base0B: '#54be0d',\n  base0C: '#afc4db',\n  base0D: '#5ea6ea',\n  base0E: '#9b859d',\n  base0F: '#937121'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/bespin.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/brewer.js":
/*!**********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/brewer.js ***!
  \**********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'brewer',\n  author: 'timothée poisot (http://github.com/tpoisot)',\n  base00: '#0c0d0e',\n  base01: '#2e2f30',\n  base02: '#515253',\n  base03: '#737475',\n  base04: '#959697',\n  base05: '#b7b8b9',\n  base06: '#dadbdc',\n  base07: '#fcfdfe',\n  base08: '#e31a1c',\n  base09: '#e6550d',\n  base0A: '#dca060',\n  base0B: '#31a354',\n  base0C: '#80b1d3',\n  base0D: '#3182bd',\n  base0E: '#756bb1',\n  base0F: '#b15928'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/brewer.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/bright.js":
/*!**********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/bright.js ***!
  \**********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'bright',\n  author: 'chris kempson (http://chriskempson.com)',\n  base00: '#000000',\n  base01: '#303030',\n  base02: '#505050',\n  base03: '#b0b0b0',\n  base04: '#d0d0d0',\n  base05: '#e0e0e0',\n  base06: '#f5f5f5',\n  base07: '#ffffff',\n  base08: '#fb0120',\n  base09: '#fc6d24',\n  base0A: '#fda331',\n  base0B: '#a1c659',\n  base0C: '#76c7b7',\n  base0D: '#6fb3d2',\n  base0E: '#d381c3',\n  base0F: '#be643c'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/bright.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/chalk.js":
/*!*********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/chalk.js ***!
  \*********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'chalk',\n  author: 'chris kempson (http://chriskempson.com)',\n  base00: '#151515',\n  base01: '#202020',\n  base02: '#303030',\n  base03: '#505050',\n  base04: '#b0b0b0',\n  base05: '#d0d0d0',\n  base06: '#e0e0e0',\n  base07: '#f5f5f5',\n  base08: '#fb9fb1',\n  base09: '#eda987',\n  base0A: '#ddb26f',\n  base0B: '#acc267',\n  base0C: '#12cfc0',\n  base0D: '#6fc2ef',\n  base0E: '#e1a3ee',\n  base0F: '#deaf8f'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/chalk.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/codeschool.js":
/*!**************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/codeschool.js ***!
  \**************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'codeschool',\n  author: 'brettof86',\n  base00: '#232c31',\n  base01: '#1c3657',\n  base02: '#2a343a',\n  base03: '#3f4944',\n  base04: '#84898c',\n  base05: '#9ea7a6',\n  base06: '#a7cfa3',\n  base07: '#b5d8f6',\n  base08: '#2a5491',\n  base09: '#43820d',\n  base0A: '#a03b1e',\n  base0B: '#237986',\n  base0C: '#b02f30',\n  base0D: '#484d79',\n  base0E: '#c59820',\n  base0F: '#c98344'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/codeschool.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/colors.js":
/*!**********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/colors.js ***!
  \**********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'colors',\n  author: 'mrmrs (http://clrs.cc)',\n  base00: '#111111',\n  base01: '#333333',\n  base02: '#555555',\n  base03: '#777777',\n  base04: '#999999',\n  base05: '#bbbbbb',\n  base06: '#dddddd',\n  base07: '#ffffff',\n  base08: '#ff4136',\n  base09: '#ff851b',\n  base0A: '#ffdc00',\n  base0B: '#2ecc40',\n  base0C: '#7fdbff',\n  base0D: '#0074d9',\n  base0E: '#b10dc9',\n  base0F: '#85144b'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/colors.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/default.js":
/*!***********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/default.js ***!
  \***********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'default',\n  author: 'chris kempson (http://chriskempson.com)',\n  base00: '#181818',\n  base01: '#282828',\n  base02: '#383838',\n  base03: '#585858',\n  base04: '#b8b8b8',\n  base05: '#d8d8d8',\n  base06: '#e8e8e8',\n  base07: '#f8f8f8',\n  base08: '#ab4642',\n  base09: '#dc9656',\n  base0A: '#f7ca88',\n  base0B: '#a1b56c',\n  base0C: '#86c1b9',\n  base0D: '#7cafc2',\n  base0E: '#ba8baf',\n  base0F: '#a16946'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/default.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/eighties.js":
/*!************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/eighties.js ***!
  \************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'eighties',\n  author: 'chris kempson (http://chriskempson.com)',\n  base00: '#2d2d2d',\n  base01: '#393939',\n  base02: '#515151',\n  base03: '#747369',\n  base04: '#a09f93',\n  base05: '#d3d0c8',\n  base06: '#e8e6df',\n  base07: '#f2f0ec',\n  base08: '#f2777a',\n  base09: '#f99157',\n  base0A: '#ffcc66',\n  base0B: '#99cc99',\n  base0C: '#66cccc',\n  base0D: '#6699cc',\n  base0E: '#cc99cc',\n  base0F: '#d27b53'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/eighties.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/embers.js":
/*!**********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/embers.js ***!
  \**********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'embers',\n  author: 'jannik siebert (https://github.com/janniks)',\n  base00: '#16130F',\n  base01: '#2C2620',\n  base02: '#433B32',\n  base03: '#5A5047',\n  base04: '#8A8075',\n  base05: '#A39A90',\n  base06: '#BEB6AE',\n  base07: '#DBD6D1',\n  base08: '#826D57',\n  base09: '#828257',\n  base0A: '#6D8257',\n  base0B: '#57826D',\n  base0C: '#576D82',\n  base0D: '#6D5782',\n  base0E: '#82576D',\n  base0F: '#825757'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/embers.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/flat.js":
/*!********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/flat.js ***!
  \********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'flat',\n  author: 'chris kempson (http://chriskempson.com)',\n  base00: '#2C3E50',\n  base01: '#34495E',\n  base02: '#7F8C8D',\n  base03: '#95A5A6',\n  base04: '#BDC3C7',\n  base05: '#e0e0e0',\n  base06: '#f5f5f5',\n  base07: '#ECF0F1',\n  base08: '#E74C3C',\n  base09: '#E67E22',\n  base0A: '#F1C40F',\n  base0B: '#2ECC71',\n  base0C: '#1ABC9C',\n  base0D: '#3498DB',\n  base0E: '#9B59B6',\n  base0F: '#be643c'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/flat.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/google.js":
/*!**********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/google.js ***!
  \**********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'google',\n  author: 'seth wright (http://sethawright.com)',\n  base00: '#1d1f21',\n  base01: '#282a2e',\n  base02: '#373b41',\n  base03: '#969896',\n  base04: '#b4b7b4',\n  base05: '#c5c8c6',\n  base06: '#e0e0e0',\n  base07: '#ffffff',\n  base08: '#CC342B',\n  base09: '#F96A38',\n  base0A: '#FBA922',\n  base0B: '#198844',\n  base0C: '#3971ED',\n  base0D: '#3971ED',\n  base0E: '#A36AC7',\n  base0F: '#3971ED'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/google.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/grayscale.js":
/*!*************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/grayscale.js ***!
  \*************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'grayscale',\n  author: 'alexandre gavioli (https://github.com/alexx2/)',\n  base00: '#101010',\n  base01: '#252525',\n  base02: '#464646',\n  base03: '#525252',\n  base04: '#ababab',\n  base05: '#b9b9b9',\n  base06: '#e3e3e3',\n  base07: '#f7f7f7',\n  base08: '#7c7c7c',\n  base09: '#999999',\n  base0A: '#a0a0a0',\n  base0B: '#8e8e8e',\n  base0C: '#868686',\n  base0D: '#686868',\n  base0E: '#747474',\n  base0F: '#5e5e5e'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/grayscale.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/greenscreen.js":
/*!***************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/greenscreen.js ***!
  \***************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'green screen',\n  author: 'chris kempson (http://chriskempson.com)',\n  base00: '#001100',\n  base01: '#003300',\n  base02: '#005500',\n  base03: '#007700',\n  base04: '#009900',\n  base05: '#00bb00',\n  base06: '#00dd00',\n  base07: '#00ff00',\n  base08: '#007700',\n  base09: '#009900',\n  base0A: '#007700',\n  base0B: '#00bb00',\n  base0C: '#005500',\n  base0D: '#009900',\n  base0E: '#00bb00',\n  base0F: '#005500'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/greenscreen.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/harmonic.js":
/*!************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/harmonic.js ***!
  \************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'harmonic16',\n  author: 'jannik siebert (https://github.com/janniks)',\n  base00: '#0b1c2c',\n  base01: '#223b54',\n  base02: '#405c79',\n  base03: '#627e99',\n  base04: '#aabcce',\n  base05: '#cbd6e2',\n  base06: '#e5ebf1',\n  base07: '#f7f9fb',\n  base08: '#bf8b56',\n  base09: '#bfbf56',\n  base0A: '#8bbf56',\n  base0B: '#56bf8b',\n  base0C: '#568bbf',\n  base0D: '#8b56bf',\n  base0E: '#bf568b',\n  base0F: '#bf5656'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/harmonic.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/hopscotch.js":
/*!*************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/hopscotch.js ***!
  \*************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'hopscotch',\n  author: 'jan t. sott',\n  base00: '#322931',\n  base01: '#433b42',\n  base02: '#5c545b',\n  base03: '#797379',\n  base04: '#989498',\n  base05: '#b9b5b8',\n  base06: '#d5d3d5',\n  base07: '#ffffff',\n  base08: '#dd464c',\n  base09: '#fd8b19',\n  base0A: '#fdcc59',\n  base0B: '#8fc13e',\n  base0C: '#149b93',\n  base0D: '#1290bf',\n  base0E: '#c85e7c',\n  base0F: '#b33508'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/hopscotch.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/index.js":
/*!*********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/index.js ***!
  \*********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\n\nfunction _interopRequire(obj) { return obj && obj.__esModule ? obj['default'] : obj; }\n\nvar _threezerotwofour = __webpack_require__(/*! ./threezerotwofour */ \"../../node_modules/base16/lib/threezerotwofour.js\");\n\nexports.threezerotwofour = _interopRequire(_threezerotwofour);\n\nvar _apathy = __webpack_require__(/*! ./apathy */ \"../../node_modules/base16/lib/apathy.js\");\n\nexports.apathy = _interopRequire(_apathy);\n\nvar _ashes = __webpack_require__(/*! ./ashes */ \"../../node_modules/base16/lib/ashes.js\");\n\nexports.ashes = _interopRequire(_ashes);\n\nvar _atelierDune = __webpack_require__(/*! ./atelier-dune */ \"../../node_modules/base16/lib/atelier-dune.js\");\n\nexports.atelierDune = _interopRequire(_atelierDune);\n\nvar _atelierForest = __webpack_require__(/*! ./atelier-forest */ \"../../node_modules/base16/lib/atelier-forest.js\");\n\nexports.atelierForest = _interopRequire(_atelierForest);\n\nvar _atelierHeath = __webpack_require__(/*! ./atelier-heath */ \"../../node_modules/base16/lib/atelier-heath.js\");\n\nexports.atelierHeath = _interopRequire(_atelierHeath);\n\nvar _atelierLakeside = __webpack_require__(/*! ./atelier-lakeside */ \"../../node_modules/base16/lib/atelier-lakeside.js\");\n\nexports.atelierLakeside = _interopRequire(_atelierLakeside);\n\nvar _atelierSeaside = __webpack_require__(/*! ./atelier-seaside */ \"../../node_modules/base16/lib/atelier-seaside.js\");\n\nexports.atelierSeaside = _interopRequire(_atelierSeaside);\n\nvar _bespin = __webpack_require__(/*! ./bespin */ \"../../node_modules/base16/lib/bespin.js\");\n\nexports.bespin = _interopRequire(_bespin);\n\nvar _brewer = __webpack_require__(/*! ./brewer */ \"../../node_modules/base16/lib/brewer.js\");\n\nexports.brewer = _interopRequire(_brewer);\n\nvar _bright = __webpack_require__(/*! ./bright */ \"../../node_modules/base16/lib/bright.js\");\n\nexports.bright = _interopRequire(_bright);\n\nvar _chalk = __webpack_require__(/*! ./chalk */ \"../../node_modules/base16/lib/chalk.js\");\n\nexports.chalk = _interopRequire(_chalk);\n\nvar _codeschool = __webpack_require__(/*! ./codeschool */ \"../../node_modules/base16/lib/codeschool.js\");\n\nexports.codeschool = _interopRequire(_codeschool);\n\nvar _colors = __webpack_require__(/*! ./colors */ \"../../node_modules/base16/lib/colors.js\");\n\nexports.colors = _interopRequire(_colors);\n\nvar _default = __webpack_require__(/*! ./default */ \"../../node_modules/base16/lib/default.js\");\n\nexports['default'] = _interopRequire(_default);\n\nvar _eighties = __webpack_require__(/*! ./eighties */ \"../../node_modules/base16/lib/eighties.js\");\n\nexports.eighties = _interopRequire(_eighties);\n\nvar _embers = __webpack_require__(/*! ./embers */ \"../../node_modules/base16/lib/embers.js\");\n\nexports.embers = _interopRequire(_embers);\n\nvar _flat = __webpack_require__(/*! ./flat */ \"../../node_modules/base16/lib/flat.js\");\n\nexports.flat = _interopRequire(_flat);\n\nvar _google = __webpack_require__(/*! ./google */ \"../../node_modules/base16/lib/google.js\");\n\nexports.google = _interopRequire(_google);\n\nvar _grayscale = __webpack_require__(/*! ./grayscale */ \"../../node_modules/base16/lib/grayscale.js\");\n\nexports.grayscale = _interopRequire(_grayscale);\n\nvar _greenscreen = __webpack_require__(/*! ./greenscreen */ \"../../node_modules/base16/lib/greenscreen.js\");\n\nexports.greenscreen = _interopRequire(_greenscreen);\n\nvar _harmonic = __webpack_require__(/*! ./harmonic */ \"../../node_modules/base16/lib/harmonic.js\");\n\nexports.harmonic = _interopRequire(_harmonic);\n\nvar _hopscotch = __webpack_require__(/*! ./hopscotch */ \"../../node_modules/base16/lib/hopscotch.js\");\n\nexports.hopscotch = _interopRequire(_hopscotch);\n\nvar _isotope = __webpack_require__(/*! ./isotope */ \"../../node_modules/base16/lib/isotope.js\");\n\nexports.isotope = _interopRequire(_isotope);\n\nvar _marrakesh = __webpack_require__(/*! ./marrakesh */ \"../../node_modules/base16/lib/marrakesh.js\");\n\nexports.marrakesh = _interopRequire(_marrakesh);\n\nvar _mocha = __webpack_require__(/*! ./mocha */ \"../../node_modules/base16/lib/mocha.js\");\n\nexports.mocha = _interopRequire(_mocha);\n\nvar _monokai = __webpack_require__(/*! ./monokai */ \"../../node_modules/base16/lib/monokai.js\");\n\nexports.monokai = _interopRequire(_monokai);\n\nvar _ocean = __webpack_require__(/*! ./ocean */ \"../../node_modules/base16/lib/ocean.js\");\n\nexports.ocean = _interopRequire(_ocean);\n\nvar _paraiso = __webpack_require__(/*! ./paraiso */ \"../../node_modules/base16/lib/paraiso.js\");\n\nexports.paraiso = _interopRequire(_paraiso);\n\nvar _pop = __webpack_require__(/*! ./pop */ \"../../node_modules/base16/lib/pop.js\");\n\nexports.pop = _interopRequire(_pop);\n\nvar _railscasts = __webpack_require__(/*! ./railscasts */ \"../../node_modules/base16/lib/railscasts.js\");\n\nexports.railscasts = _interopRequire(_railscasts);\n\nvar _shapeshifter = __webpack_require__(/*! ./shapeshifter */ \"../../node_modules/base16/lib/shapeshifter.js\");\n\nexports.shapeshifter = _interopRequire(_shapeshifter);\n\nvar _solarized = __webpack_require__(/*! ./solarized */ \"../../node_modules/base16/lib/solarized.js\");\n\nexports.solarized = _interopRequire(_solarized);\n\nvar _summerfruit = __webpack_require__(/*! ./summerfruit */ \"../../node_modules/base16/lib/summerfruit.js\");\n\nexports.summerfruit = _interopRequire(_summerfruit);\n\nvar _tomorrow = __webpack_require__(/*! ./tomorrow */ \"../../node_modules/base16/lib/tomorrow.js\");\n\nexports.tomorrow = _interopRequire(_tomorrow);\n\nvar _tube = __webpack_require__(/*! ./tube */ \"../../node_modules/base16/lib/tube.js\");\n\nexports.tube = _interopRequire(_tube);\n\nvar _twilight = __webpack_require__(/*! ./twilight */ \"../../node_modules/base16/lib/twilight.js\");\n\nexports.twilight = _interopRequire(_twilight);\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/index.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/isotope.js":
/*!***********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/isotope.js ***!
  \***********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'isotope',\n  author: 'jan t. sott',\n  base00: '#000000',\n  base01: '#404040',\n  base02: '#606060',\n  base03: '#808080',\n  base04: '#c0c0c0',\n  base05: '#d0d0d0',\n  base06: '#e0e0e0',\n  base07: '#ffffff',\n  base08: '#ff0000',\n  base09: '#ff9900',\n  base0A: '#ff0099',\n  base0B: '#33ff00',\n  base0C: '#00ffff',\n  base0D: '#0066ff',\n  base0E: '#cc00ff',\n  base0F: '#3300ff'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/isotope.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/marrakesh.js":
/*!*************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/marrakesh.js ***!
  \*************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'marrakesh',\n  author: 'alexandre gavioli (http://github.com/alexx2/)',\n  base00: '#201602',\n  base01: '#302e00',\n  base02: '#5f5b17',\n  base03: '#6c6823',\n  base04: '#86813b',\n  base05: '#948e48',\n  base06: '#ccc37a',\n  base07: '#faf0a5',\n  base08: '#c35359',\n  base09: '#b36144',\n  base0A: '#a88339',\n  base0B: '#18974e',\n  base0C: '#75a738',\n  base0D: '#477ca1',\n  base0E: '#8868b3',\n  base0F: '#b3588e'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/marrakesh.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/mocha.js":
/*!*********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/mocha.js ***!
  \*********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'mocha',\n  author: 'chris kempson (http://chriskempson.com)',\n  base00: '#3B3228',\n  base01: '#534636',\n  base02: '#645240',\n  base03: '#7e705a',\n  base04: '#b8afad',\n  base05: '#d0c8c6',\n  base06: '#e9e1dd',\n  base07: '#f5eeeb',\n  base08: '#cb6077',\n  base09: '#d28b71',\n  base0A: '#f4bc87',\n  base0B: '#beb55b',\n  base0C: '#7bbda4',\n  base0D: '#8ab3b5',\n  base0E: '#a89bb9',\n  base0F: '#bb9584'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/mocha.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/monokai.js":
/*!***********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/monokai.js ***!
  \***********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'monokai',\n  author: 'wimer hazenberg (http://www.monokai.nl)',\n  base00: '#272822',\n  base01: '#383830',\n  base02: '#49483e',\n  base03: '#75715e',\n  base04: '#a59f85',\n  base05: '#f8f8f2',\n  base06: '#f5f4f1',\n  base07: '#f9f8f5',\n  base08: '#f92672',\n  base09: '#fd971f',\n  base0A: '#f4bf75',\n  base0B: '#a6e22e',\n  base0C: '#a1efe4',\n  base0D: '#66d9ef',\n  base0E: '#ae81ff',\n  base0F: '#cc6633'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/monokai.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/ocean.js":
/*!*********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/ocean.js ***!
  \*********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'ocean',\n  author: 'chris kempson (http://chriskempson.com)',\n  base00: '#2b303b',\n  base01: '#343d46',\n  base02: '#4f5b66',\n  base03: '#65737e',\n  base04: '#a7adba',\n  base05: '#c0c5ce',\n  base06: '#dfe1e8',\n  base07: '#eff1f5',\n  base08: '#bf616a',\n  base09: '#d08770',\n  base0A: '#ebcb8b',\n  base0B: '#a3be8c',\n  base0C: '#96b5b4',\n  base0D: '#8fa1b3',\n  base0E: '#b48ead',\n  base0F: '#ab7967'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/ocean.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/paraiso.js":
/*!***********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/paraiso.js ***!
  \***********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'paraiso',\n  author: 'jan t. sott',\n  base00: '#2f1e2e',\n  base01: '#41323f',\n  base02: '#4f424c',\n  base03: '#776e71',\n  base04: '#8d8687',\n  base05: '#a39e9b',\n  base06: '#b9b6b0',\n  base07: '#e7e9db',\n  base08: '#ef6155',\n  base09: '#f99b15',\n  base0A: '#fec418',\n  base0B: '#48b685',\n  base0C: '#5bc4bf',\n  base0D: '#06b6ef',\n  base0E: '#815ba4',\n  base0F: '#e96ba8'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/paraiso.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/pop.js":
/*!*******************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/pop.js ***!
  \*******************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'pop',\n  author: 'chris kempson (http://chriskempson.com)',\n  base00: '#000000',\n  base01: '#202020',\n  base02: '#303030',\n  base03: '#505050',\n  base04: '#b0b0b0',\n  base05: '#d0d0d0',\n  base06: '#e0e0e0',\n  base07: '#ffffff',\n  base08: '#eb008a',\n  base09: '#f29333',\n  base0A: '#f8ca12',\n  base0B: '#37b349',\n  base0C: '#00aabb',\n  base0D: '#0e5a94',\n  base0E: '#b31e8d',\n  base0F: '#7a2d00'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/pop.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/railscasts.js":
/*!**************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/railscasts.js ***!
  \**************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'railscasts',\n  author: 'ryan bates (http://railscasts.com)',\n  base00: '#2b2b2b',\n  base01: '#272935',\n  base02: '#3a4055',\n  base03: '#5a647e',\n  base04: '#d4cfc9',\n  base05: '#e6e1dc',\n  base06: '#f4f1ed',\n  base07: '#f9f7f3',\n  base08: '#da4939',\n  base09: '#cc7833',\n  base0A: '#ffc66d',\n  base0B: '#a5c261',\n  base0C: '#519f50',\n  base0D: '#6d9cbe',\n  base0E: '#b6b3eb',\n  base0F: '#bc9458'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/railscasts.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/shapeshifter.js":
/*!****************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/shapeshifter.js ***!
  \****************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'shapeshifter',\n  author: 'tyler benziger (http://tybenz.com)',\n  base00: '#000000',\n  base01: '#040404',\n  base02: '#102015',\n  base03: '#343434',\n  base04: '#555555',\n  base05: '#ababab',\n  base06: '#e0e0e0',\n  base07: '#f9f9f9',\n  base08: '#e92f2f',\n  base09: '#e09448',\n  base0A: '#dddd13',\n  base0B: '#0ed839',\n  base0C: '#23edda',\n  base0D: '#3b48e3',\n  base0E: '#f996e2',\n  base0F: '#69542d'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/shapeshifter.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/solarized.js":
/*!*************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/solarized.js ***!
  \*************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'solarized',\n  author: 'ethan schoonover (http://ethanschoonover.com/solarized)',\n  base00: '#002b36',\n  base01: '#073642',\n  base02: '#586e75',\n  base03: '#657b83',\n  base04: '#839496',\n  base05: '#93a1a1',\n  base06: '#eee8d5',\n  base07: '#fdf6e3',\n  base08: '#dc322f',\n  base09: '#cb4b16',\n  base0A: '#b58900',\n  base0B: '#859900',\n  base0C: '#2aa198',\n  base0D: '#268bd2',\n  base0E: '#6c71c4',\n  base0F: '#d33682'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/solarized.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/summerfruit.js":
/*!***************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/summerfruit.js ***!
  \***************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'summerfruit',\n  author: 'christopher corley (http://cscorley.github.io/)',\n  base00: '#151515',\n  base01: '#202020',\n  base02: '#303030',\n  base03: '#505050',\n  base04: '#B0B0B0',\n  base05: '#D0D0D0',\n  base06: '#E0E0E0',\n  base07: '#FFFFFF',\n  base08: '#FF0086',\n  base09: '#FD8900',\n  base0A: '#ABA800',\n  base0B: '#00C918',\n  base0C: '#1faaaa',\n  base0D: '#3777E6',\n  base0E: '#AD00A1',\n  base0F: '#cc6633'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/summerfruit.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/threezerotwofour.js":
/*!********************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/threezerotwofour.js ***!
  \********************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'threezerotwofour',\n  author: 'jan t. sott (http://github.com/idleberg)',\n  base00: '#090300',\n  base01: '#3a3432',\n  base02: '#4a4543',\n  base03: '#5c5855',\n  base04: '#807d7c',\n  base05: '#a5a2a2',\n  base06: '#d6d5d4',\n  base07: '#f7f7f7',\n  base08: '#db2d20',\n  base09: '#e8bbd0',\n  base0A: '#fded02',\n  base0B: '#01a252',\n  base0C: '#b5e4f4',\n  base0D: '#01a0e4',\n  base0E: '#a16a94',\n  base0F: '#cdab53'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/threezerotwofour.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/tomorrow.js":
/*!************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/tomorrow.js ***!
  \************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'tomorrow',\n  author: 'chris kempson (http://chriskempson.com)',\n  base00: '#1d1f21',\n  base01: '#282a2e',\n  base02: '#373b41',\n  base03: '#969896',\n  base04: '#b4b7b4',\n  base05: '#c5c8c6',\n  base06: '#e0e0e0',\n  base07: '#ffffff',\n  base08: '#cc6666',\n  base09: '#de935f',\n  base0A: '#f0c674',\n  base0B: '#b5bd68',\n  base0C: '#8abeb7',\n  base0D: '#81a2be',\n  base0E: '#b294bb',\n  base0F: '#a3685a'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/tomorrow.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/tube.js":
/*!********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/tube.js ***!
  \********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'london tube',\n  author: 'jan t. sott',\n  base00: '#231f20',\n  base01: '#1c3f95',\n  base02: '#5a5758',\n  base03: '#737171',\n  base04: '#959ca1',\n  base05: '#d9d8d8',\n  base06: '#e7e7e8',\n  base07: '#ffffff',\n  base08: '#ee2e24',\n  base09: '#f386a1',\n  base0A: '#ffd204',\n  base0B: '#00853e',\n  base0C: '#85cebc',\n  base0D: '#009ddc',\n  base0E: '#98005d',\n  base0F: '#b06110'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/tube.js?");

/***/ }),

/***/ "../../node_modules/base16/lib/twilight.js":
/*!************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/twilight.js ***!
  \************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nexports.__esModule = true;\nexports['default'] = {\n  scheme: 'twilight',\n  author: 'david hart (http://hart-dev.com)',\n  base00: '#1e1e1e',\n  base01: '#323537',\n  base02: '#464b50',\n  base03: '#5f5a60',\n  base04: '#838184',\n  base05: '#a7a7a7',\n  base06: '#c3c3c3',\n  base07: '#ffffff',\n  base08: '#cf6a4c',\n  base09: '#cda869',\n  base0A: '#f9ee98',\n  base0B: '#8f9d6a',\n  base0C: '#afc4db',\n  base0D: '#7587a6',\n  base0E: '#9b859d',\n  base0F: '#9b703f'\n};\nmodule.exports = exports['default'];\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/base16/lib/twilight.js?");

/***/ }),

/***/ "../../node_modules/lodash.curry/index.js":
/*!***********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/lodash.curry/index.js ***!
  \***********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("/* WEBPACK VAR INJECTION */(function(global) {/**\n * lodash (Custom Build) <https://lodash.com/>\n * Build: `lodash modularize exports=\"npm\" -o ./`\n * Copyright jQuery Foundation and other contributors <https://jquery.org/>\n * Released under MIT license <https://lodash.com/license>\n * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>\n * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors\n */\n\n/** Used as the `TypeError` message for \"Functions\" methods. */\nvar FUNC_ERROR_TEXT = 'Expected a function';\n\n/** Used as the internal argument placeholder. */\nvar PLACEHOLDER = '__lodash_placeholder__';\n\n/** Used to compose bitmasks for function metadata. */\nvar BIND_FLAG = 1,\n    BIND_KEY_FLAG = 2,\n    CURRY_BOUND_FLAG = 4,\n    CURRY_FLAG = 8,\n    CURRY_RIGHT_FLAG = 16,\n    PARTIAL_FLAG = 32,\n    PARTIAL_RIGHT_FLAG = 64,\n    ARY_FLAG = 128,\n    REARG_FLAG = 256,\n    FLIP_FLAG = 512;\n\n/** Used as references for various `Number` constants. */\nvar INFINITY = 1 / 0,\n    MAX_SAFE_INTEGER = 9007199254740991,\n    MAX_INTEGER = 1.7976931348623157e+308,\n    NAN = 0 / 0;\n\n/** Used to associate wrap methods with their bit flags. */\nvar wrapFlags = [\n  ['ary', ARY_FLAG],\n  ['bind', BIND_FLAG],\n  ['bindKey', BIND_KEY_FLAG],\n  ['curry', CURRY_FLAG],\n  ['curryRight', CURRY_RIGHT_FLAG],\n  ['flip', FLIP_FLAG],\n  ['partial', PARTIAL_FLAG],\n  ['partialRight', PARTIAL_RIGHT_FLAG],\n  ['rearg', REARG_FLAG]\n];\n\n/** `Object#toString` result references. */\nvar funcTag = '[object Function]',\n    genTag = '[object GeneratorFunction]',\n    symbolTag = '[object Symbol]';\n\n/**\n * Used to match `RegExp`\n * [syntax characters](http://ecma-international.org/ecma-262/7.0/#sec-patterns).\n */\nvar reRegExpChar = /[\\\\^$.*+?()[\\]{}|]/g;\n\n/** Used to match leading and trailing whitespace. */\nvar reTrim = /^\\s+|\\s+$/g;\n\n/** Used to match wrap detail comments. */\nvar reWrapComment = /\\{(?:\\n\\/\\* \\[wrapped with .+\\] \\*\\/)?\\n?/,\n    reWrapDetails = /\\{\\n\\/\\* \\[wrapped with (.+)\\] \\*/,\n    reSplitDetails = /,? & /;\n\n/** Used to detect bad signed hexadecimal string values. */\nvar reIsBadHex = /^[-+]0x[0-9a-f]+$/i;\n\n/** Used to detect binary string values. */\nvar reIsBinary = /^0b[01]+$/i;\n\n/** Used to detect host constructors (Safari). */\nvar reIsHostCtor = /^\\[object .+?Constructor\\]$/;\n\n/** Used to detect octal string values. */\nvar reIsOctal = /^0o[0-7]+$/i;\n\n/** Used to detect unsigned integer values. */\nvar reIsUint = /^(?:0|[1-9]\\d*)$/;\n\n/** Built-in method references without a dependency on `root`. */\nvar freeParseInt = parseInt;\n\n/** Detect free variable `global` from Node.js. */\nvar freeGlobal = typeof global == 'object' && global && global.Object === Object && global;\n\n/** Detect free variable `self`. */\nvar freeSelf = typeof self == 'object' && self && self.Object === Object && self;\n\n/** Used as a reference to the global object. */\nvar root = freeGlobal || freeSelf || Function('return this')();\n\n/**\n * A faster alternative to `Function#apply`, this function invokes `func`\n * with the `this` binding of `thisArg` and the arguments of `args`.\n *\n * @private\n * @param {Function} func The function to invoke.\n * @param {*} thisArg The `this` binding of `func`.\n * @param {Array} args The arguments to invoke `func` with.\n * @returns {*} Returns the result of `func`.\n */\nfunction apply(func, thisArg, args) {\n  switch (args.length) {\n    case 0: return func.call(thisArg);\n    case 1: return func.call(thisArg, args[0]);\n    case 2: return func.call(thisArg, args[0], args[1]);\n    case 3: return func.call(thisArg, args[0], args[1], args[2]);\n  }\n  return func.apply(thisArg, args);\n}\n\n/**\n * A specialized version of `_.forEach` for arrays without support for\n * iteratee shorthands.\n *\n * @private\n * @param {Array} [array] The array to iterate over.\n * @param {Function} iteratee The function invoked per iteration.\n * @returns {Array} Returns `array`.\n */\nfunction arrayEach(array, iteratee) {\n  var index = -1,\n      length = array ? array.length : 0;\n\n  while (++index < length) {\n    if (iteratee(array[index], index, array) === false) {\n      break;\n    }\n  }\n  return array;\n}\n\n/**\n * A specialized version of `_.includes` for arrays without support for\n * specifying an index to search from.\n *\n * @private\n * @param {Array} [array] The array to inspect.\n * @param {*} target The value to search for.\n * @returns {boolean} Returns `true` if `target` is found, else `false`.\n */\nfunction arrayIncludes(array, value) {\n  var length = array ? array.length : 0;\n  return !!length && baseIndexOf(array, value, 0) > -1;\n}\n\n/**\n * The base implementation of `_.findIndex` and `_.findLastIndex` without\n * support for iteratee shorthands.\n *\n * @private\n * @param {Array} array The array to inspect.\n * @param {Function} predicate The function invoked per iteration.\n * @param {number} fromIndex The index to search from.\n * @param {boolean} [fromRight] Specify iterating from right to left.\n * @returns {number} Returns the index of the matched value, else `-1`.\n */\nfunction baseFindIndex(array, predicate, fromIndex, fromRight) {\n  var length = array.length,\n      index = fromIndex + (fromRight ? 1 : -1);\n\n  while ((fromRight ? index-- : ++index < length)) {\n    if (predicate(array[index], index, array)) {\n      return index;\n    }\n  }\n  return -1;\n}\n\n/**\n * The base implementation of `_.indexOf` without `fromIndex` bounds checks.\n *\n * @private\n * @param {Array} array The array to inspect.\n * @param {*} value The value to search for.\n * @param {number} fromIndex The index to search from.\n * @returns {number} Returns the index of the matched value, else `-1`.\n */\nfunction baseIndexOf(array, value, fromIndex) {\n  if (value !== value) {\n    return baseFindIndex(array, baseIsNaN, fromIndex);\n  }\n  var index = fromIndex - 1,\n      length = array.length;\n\n  while (++index < length) {\n    if (array[index] === value) {\n      return index;\n    }\n  }\n  return -1;\n}\n\n/**\n * The base implementation of `_.isNaN` without support for number objects.\n *\n * @private\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is `NaN`, else `false`.\n */\nfunction baseIsNaN(value) {\n  return value !== value;\n}\n\n/**\n * Gets the number of `placeholder` occurrences in `array`.\n *\n * @private\n * @param {Array} array The array to inspect.\n * @param {*} placeholder The placeholder to search for.\n * @returns {number} Returns the placeholder count.\n */\nfunction countHolders(array, placeholder) {\n  var length = array.length,\n      result = 0;\n\n  while (length--) {\n    if (array[length] === placeholder) {\n      result++;\n    }\n  }\n  return result;\n}\n\n/**\n * Gets the value at `key` of `object`.\n *\n * @private\n * @param {Object} [object] The object to query.\n * @param {string} key The key of the property to get.\n * @returns {*} Returns the property value.\n */\nfunction getValue(object, key) {\n  return object == null ? undefined : object[key];\n}\n\n/**\n * Checks if `value` is a host object in IE < 9.\n *\n * @private\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is a host object, else `false`.\n */\nfunction isHostObject(value) {\n  // Many host objects are `Object` objects that can coerce to strings\n  // despite having improperly defined `toString` methods.\n  var result = false;\n  if (value != null && typeof value.toString != 'function') {\n    try {\n      result = !!(value + '');\n    } catch (e) {}\n  }\n  return result;\n}\n\n/**\n * Replaces all `placeholder` elements in `array` with an internal placeholder\n * and returns an array of their indexes.\n *\n * @private\n * @param {Array} array The array to modify.\n * @param {*} placeholder The placeholder to replace.\n * @returns {Array} Returns the new array of placeholder indexes.\n */\nfunction replaceHolders(array, placeholder) {\n  var index = -1,\n      length = array.length,\n      resIndex = 0,\n      result = [];\n\n  while (++index < length) {\n    var value = array[index];\n    if (value === placeholder || value === PLACEHOLDER) {\n      array[index] = PLACEHOLDER;\n      result[resIndex++] = index;\n    }\n  }\n  return result;\n}\n\n/** Used for built-in method references. */\nvar funcProto = Function.prototype,\n    objectProto = Object.prototype;\n\n/** Used to detect overreaching core-js shims. */\nvar coreJsData = root['__core-js_shared__'];\n\n/** Used to detect methods masquerading as native. */\nvar maskSrcKey = (function() {\n  var uid = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || '');\n  return uid ? ('Symbol(src)_1.' + uid) : '';\n}());\n\n/** Used to resolve the decompiled source of functions. */\nvar funcToString = funcProto.toString;\n\n/** Used to check objects for own properties. */\nvar hasOwnProperty = objectProto.hasOwnProperty;\n\n/**\n * Used to resolve the\n * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)\n * of values.\n */\nvar objectToString = objectProto.toString;\n\n/** Used to detect if a method is native. */\nvar reIsNative = RegExp('^' +\n  funcToString.call(hasOwnProperty).replace(reRegExpChar, '\\\\$&')\n  .replace(/hasOwnProperty|(function).*?(?=\\\\\\()| for .+?(?=\\\\\\])/g, '$1.*?') + '$'\n);\n\n/** Built-in value references. */\nvar objectCreate = Object.create;\n\n/* Built-in method references for those with the same name as other `lodash` methods. */\nvar nativeMax = Math.max,\n    nativeMin = Math.min;\n\n/* Used to set `toString` methods. */\nvar defineProperty = (function() {\n  var func = getNative(Object, 'defineProperty'),\n      name = getNative.name;\n\n  return (name && name.length > 2) ? func : undefined;\n}());\n\n/**\n * The base implementation of `_.create` without support for assigning\n * properties to the created object.\n *\n * @private\n * @param {Object} prototype The object to inherit from.\n * @returns {Object} Returns the new object.\n */\nfunction baseCreate(proto) {\n  return isObject(proto) ? objectCreate(proto) : {};\n}\n\n/**\n * The base implementation of `_.isNative` without bad shim checks.\n *\n * @private\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is a native function,\n *  else `false`.\n */\nfunction baseIsNative(value) {\n  if (!isObject(value) || isMasked(value)) {\n    return false;\n  }\n  var pattern = (isFunction(value) || isHostObject(value)) ? reIsNative : reIsHostCtor;\n  return pattern.test(toSource(value));\n}\n\n/**\n * Creates an array that is the composition of partially applied arguments,\n * placeholders, and provided arguments into a single array of arguments.\n *\n * @private\n * @param {Array} args The provided arguments.\n * @param {Array} partials The arguments to prepend to those provided.\n * @param {Array} holders The `partials` placeholder indexes.\n * @params {boolean} [isCurried] Specify composing for a curried function.\n * @returns {Array} Returns the new array of composed arguments.\n */\nfunction composeArgs(args, partials, holders, isCurried) {\n  var argsIndex = -1,\n      argsLength = args.length,\n      holdersLength = holders.length,\n      leftIndex = -1,\n      leftLength = partials.length,\n      rangeLength = nativeMax(argsLength - holdersLength, 0),\n      result = Array(leftLength + rangeLength),\n      isUncurried = !isCurried;\n\n  while (++leftIndex < leftLength) {\n    result[leftIndex] = partials[leftIndex];\n  }\n  while (++argsIndex < holdersLength) {\n    if (isUncurried || argsIndex < argsLength) {\n      result[holders[argsIndex]] = args[argsIndex];\n    }\n  }\n  while (rangeLength--) {\n    result[leftIndex++] = args[argsIndex++];\n  }\n  return result;\n}\n\n/**\n * This function is like `composeArgs` except that the arguments composition\n * is tailored for `_.partialRight`.\n *\n * @private\n * @param {Array} args The provided arguments.\n * @param {Array} partials The arguments to append to those provided.\n * @param {Array} holders The `partials` placeholder indexes.\n * @params {boolean} [isCurried] Specify composing for a curried function.\n * @returns {Array} Returns the new array of composed arguments.\n */\nfunction composeArgsRight(args, partials, holders, isCurried) {\n  var argsIndex = -1,\n      argsLength = args.length,\n      holdersIndex = -1,\n      holdersLength = holders.length,\n      rightIndex = -1,\n      rightLength = partials.length,\n      rangeLength = nativeMax(argsLength - holdersLength, 0),\n      result = Array(rangeLength + rightLength),\n      isUncurried = !isCurried;\n\n  while (++argsIndex < rangeLength) {\n    result[argsIndex] = args[argsIndex];\n  }\n  var offset = argsIndex;\n  while (++rightIndex < rightLength) {\n    result[offset + rightIndex] = partials[rightIndex];\n  }\n  while (++holdersIndex < holdersLength) {\n    if (isUncurried || argsIndex < argsLength) {\n      result[offset + holders[holdersIndex]] = args[argsIndex++];\n    }\n  }\n  return result;\n}\n\n/**\n * Copies the values of `source` to `array`.\n *\n * @private\n * @param {Array} source The array to copy values from.\n * @param {Array} [array=[]] The array to copy values to.\n * @returns {Array} Returns `array`.\n */\nfunction copyArray(source, array) {\n  var index = -1,\n      length = source.length;\n\n  array || (array = Array(length));\n  while (++index < length) {\n    array[index] = source[index];\n  }\n  return array;\n}\n\n/**\n * Creates a function that wraps `func` to invoke it with the optional `this`\n * binding of `thisArg`.\n *\n * @private\n * @param {Function} func The function to wrap.\n * @param {number} bitmask The bitmask flags. See `createWrap` for more details.\n * @param {*} [thisArg] The `this` binding of `func`.\n * @returns {Function} Returns the new wrapped function.\n */\nfunction createBind(func, bitmask, thisArg) {\n  var isBind = bitmask & BIND_FLAG,\n      Ctor = createCtor(func);\n\n  function wrapper() {\n    var fn = (this && this !== root && this instanceof wrapper) ? Ctor : func;\n    return fn.apply(isBind ? thisArg : this, arguments);\n  }\n  return wrapper;\n}\n\n/**\n * Creates a function that produces an instance of `Ctor` regardless of\n * whether it was invoked as part of a `new` expression or by `call` or `apply`.\n *\n * @private\n * @param {Function} Ctor The constructor to wrap.\n * @returns {Function} Returns the new wrapped function.\n */\nfunction createCtor(Ctor) {\n  return function() {\n    // Use a `switch` statement to work with class constructors. See\n    // http://ecma-international.org/ecma-262/7.0/#sec-ecmascript-function-objects-call-thisargument-argumentslist\n    // for more details.\n    var args = arguments;\n    switch (args.length) {\n      case 0: return new Ctor;\n      case 1: return new Ctor(args[0]);\n      case 2: return new Ctor(args[0], args[1]);\n      case 3: return new Ctor(args[0], args[1], args[2]);\n      case 4: return new Ctor(args[0], args[1], args[2], args[3]);\n      case 5: return new Ctor(args[0], args[1], args[2], args[3], args[4]);\n      case 6: return new Ctor(args[0], args[1], args[2], args[3], args[4], args[5]);\n      case 7: return new Ctor(args[0], args[1], args[2], args[3], args[4], args[5], args[6]);\n    }\n    var thisBinding = baseCreate(Ctor.prototype),\n        result = Ctor.apply(thisBinding, args);\n\n    // Mimic the constructor's `return` behavior.\n    // See https://es5.github.io/#x13.2.2 for more details.\n    return isObject(result) ? result : thisBinding;\n  };\n}\n\n/**\n * Creates a function that wraps `func` to enable currying.\n *\n * @private\n * @param {Function} func The function to wrap.\n * @param {number} bitmask The bitmask flags. See `createWrap` for more details.\n * @param {number} arity The arity of `func`.\n * @returns {Function} Returns the new wrapped function.\n */\nfunction createCurry(func, bitmask, arity) {\n  var Ctor = createCtor(func);\n\n  function wrapper() {\n    var length = arguments.length,\n        args = Array(length),\n        index = length,\n        placeholder = getHolder(wrapper);\n\n    while (index--) {\n      args[index] = arguments[index];\n    }\n    var holders = (length < 3 && args[0] !== placeholder && args[length - 1] !== placeholder)\n      ? []\n      : replaceHolders(args, placeholder);\n\n    length -= holders.length;\n    if (length < arity) {\n      return createRecurry(\n        func, bitmask, createHybrid, wrapper.placeholder, undefined,\n        args, holders, undefined, undefined, arity - length);\n    }\n    var fn = (this && this !== root && this instanceof wrapper) ? Ctor : func;\n    return apply(fn, this, args);\n  }\n  return wrapper;\n}\n\n/**\n * Creates a function that wraps `func` to invoke it with optional `this`\n * binding of `thisArg`, partial application, and currying.\n *\n * @private\n * @param {Function|string} func The function or method name to wrap.\n * @param {number} bitmask The bitmask flags. See `createWrap` for more details.\n * @param {*} [thisArg] The `this` binding of `func`.\n * @param {Array} [partials] The arguments to prepend to those provided to\n *  the new function.\n * @param {Array} [holders] The `partials` placeholder indexes.\n * @param {Array} [partialsRight] The arguments to append to those provided\n *  to the new function.\n * @param {Array} [holdersRight] The `partialsRight` placeholder indexes.\n * @param {Array} [argPos] The argument positions of the new function.\n * @param {number} [ary] The arity cap of `func`.\n * @param {number} [arity] The arity of `func`.\n * @returns {Function} Returns the new wrapped function.\n */\nfunction createHybrid(func, bitmask, thisArg, partials, holders, partialsRight, holdersRight, argPos, ary, arity) {\n  var isAry = bitmask & ARY_FLAG,\n      isBind = bitmask & BIND_FLAG,\n      isBindKey = bitmask & BIND_KEY_FLAG,\n      isCurried = bitmask & (CURRY_FLAG | CURRY_RIGHT_FLAG),\n      isFlip = bitmask & FLIP_FLAG,\n      Ctor = isBindKey ? undefined : createCtor(func);\n\n  function wrapper() {\n    var length = arguments.length,\n        args = Array(length),\n        index = length;\n\n    while (index--) {\n      args[index] = arguments[index];\n    }\n    if (isCurried) {\n      var placeholder = getHolder(wrapper),\n          holdersCount = countHolders(args, placeholder);\n    }\n    if (partials) {\n      args = composeArgs(args, partials, holders, isCurried);\n    }\n    if (partialsRight) {\n      args = composeArgsRight(args, partialsRight, holdersRight, isCurried);\n    }\n    length -= holdersCount;\n    if (isCurried && length < arity) {\n      var newHolders = replaceHolders(args, placeholder);\n      return createRecurry(\n        func, bitmask, createHybrid, wrapper.placeholder, thisArg,\n        args, newHolders, argPos, ary, arity - length\n      );\n    }\n    var thisBinding = isBind ? thisArg : this,\n        fn = isBindKey ? thisBinding[func] : func;\n\n    length = args.length;\n    if (argPos) {\n      args = reorder(args, argPos);\n    } else if (isFlip && length > 1) {\n      args.reverse();\n    }\n    if (isAry && ary < length) {\n      args.length = ary;\n    }\n    if (this && this !== root && this instanceof wrapper) {\n      fn = Ctor || createCtor(fn);\n    }\n    return fn.apply(thisBinding, args);\n  }\n  return wrapper;\n}\n\n/**\n * Creates a function that wraps `func` to invoke it with the `this` binding\n * of `thisArg` and `partials` prepended to the arguments it receives.\n *\n * @private\n * @param {Function} func The function to wrap.\n * @param {number} bitmask The bitmask flags. See `createWrap` for more details.\n * @param {*} thisArg The `this` binding of `func`.\n * @param {Array} partials The arguments to prepend to those provided to\n *  the new function.\n * @returns {Function} Returns the new wrapped function.\n */\nfunction createPartial(func, bitmask, thisArg, partials) {\n  var isBind = bitmask & BIND_FLAG,\n      Ctor = createCtor(func);\n\n  function wrapper() {\n    var argsIndex = -1,\n        argsLength = arguments.length,\n        leftIndex = -1,\n        leftLength = partials.length,\n        args = Array(leftLength + argsLength),\n        fn = (this && this !== root && this instanceof wrapper) ? Ctor : func;\n\n    while (++leftIndex < leftLength) {\n      args[leftIndex] = partials[leftIndex];\n    }\n    while (argsLength--) {\n      args[leftIndex++] = arguments[++argsIndex];\n    }\n    return apply(fn, isBind ? thisArg : this, args);\n  }\n  return wrapper;\n}\n\n/**\n * Creates a function that wraps `func` to continue currying.\n *\n * @private\n * @param {Function} func The function to wrap.\n * @param {number} bitmask The bitmask flags. See `createWrap` for more details.\n * @param {Function} wrapFunc The function to create the `func` wrapper.\n * @param {*} placeholder The placeholder value.\n * @param {*} [thisArg] The `this` binding of `func`.\n * @param {Array} [partials] The arguments to prepend to those provided to\n *  the new function.\n * @param {Array} [holders] The `partials` placeholder indexes.\n * @param {Array} [argPos] The argument positions of the new function.\n * @param {number} [ary] The arity cap of `func`.\n * @param {number} [arity] The arity of `func`.\n * @returns {Function} Returns the new wrapped function.\n */\nfunction createRecurry(func, bitmask, wrapFunc, placeholder, thisArg, partials, holders, argPos, ary, arity) {\n  var isCurry = bitmask & CURRY_FLAG,\n      newHolders = isCurry ? holders : undefined,\n      newHoldersRight = isCurry ? undefined : holders,\n      newPartials = isCurry ? partials : undefined,\n      newPartialsRight = isCurry ? undefined : partials;\n\n  bitmask |= (isCurry ? PARTIAL_FLAG : PARTIAL_RIGHT_FLAG);\n  bitmask &= ~(isCurry ? PARTIAL_RIGHT_FLAG : PARTIAL_FLAG);\n\n  if (!(bitmask & CURRY_BOUND_FLAG)) {\n    bitmask &= ~(BIND_FLAG | BIND_KEY_FLAG);\n  }\n\n  var result = wrapFunc(func, bitmask, thisArg, newPartials, newHolders, newPartialsRight, newHoldersRight, argPos, ary, arity);\n  result.placeholder = placeholder;\n  return setWrapToString(result, func, bitmask);\n}\n\n/**\n * Creates a function that either curries or invokes `func` with optional\n * `this` binding and partially applied arguments.\n *\n * @private\n * @param {Function|string} func The function or method name to wrap.\n * @param {number} bitmask The bitmask flags.\n *  The bitmask may be composed of the following flags:\n *     1 - `_.bind`\n *     2 - `_.bindKey`\n *     4 - `_.curry` or `_.curryRight` of a bound function\n *     8 - `_.curry`\n *    16 - `_.curryRight`\n *    32 - `_.partial`\n *    64 - `_.partialRight`\n *   128 - `_.rearg`\n *   256 - `_.ary`\n *   512 - `_.flip`\n * @param {*} [thisArg] The `this` binding of `func`.\n * @param {Array} [partials] The arguments to be partially applied.\n * @param {Array} [holders] The `partials` placeholder indexes.\n * @param {Array} [argPos] The argument positions of the new function.\n * @param {number} [ary] The arity cap of `func`.\n * @param {number} [arity] The arity of `func`.\n * @returns {Function} Returns the new wrapped function.\n */\nfunction createWrap(func, bitmask, thisArg, partials, holders, argPos, ary, arity) {\n  var isBindKey = bitmask & BIND_KEY_FLAG;\n  if (!isBindKey && typeof func != 'function') {\n    throw new TypeError(FUNC_ERROR_TEXT);\n  }\n  var length = partials ? partials.length : 0;\n  if (!length) {\n    bitmask &= ~(PARTIAL_FLAG | PARTIAL_RIGHT_FLAG);\n    partials = holders = undefined;\n  }\n  ary = ary === undefined ? ary : nativeMax(toInteger(ary), 0);\n  arity = arity === undefined ? arity : toInteger(arity);\n  length -= holders ? holders.length : 0;\n\n  if (bitmask & PARTIAL_RIGHT_FLAG) {\n    var partialsRight = partials,\n        holdersRight = holders;\n\n    partials = holders = undefined;\n  }\n\n  var newData = [\n    func, bitmask, thisArg, partials, holders, partialsRight, holdersRight,\n    argPos, ary, arity\n  ];\n\n  func = newData[0];\n  bitmask = newData[1];\n  thisArg = newData[2];\n  partials = newData[3];\n  holders = newData[4];\n  arity = newData[9] = newData[9] == null\n    ? (isBindKey ? 0 : func.length)\n    : nativeMax(newData[9] - length, 0);\n\n  if (!arity && bitmask & (CURRY_FLAG | CURRY_RIGHT_FLAG)) {\n    bitmask &= ~(CURRY_FLAG | CURRY_RIGHT_FLAG);\n  }\n  if (!bitmask || bitmask == BIND_FLAG) {\n    var result = createBind(func, bitmask, thisArg);\n  } else if (bitmask == CURRY_FLAG || bitmask == CURRY_RIGHT_FLAG) {\n    result = createCurry(func, bitmask, arity);\n  } else if ((bitmask == PARTIAL_FLAG || bitmask == (BIND_FLAG | PARTIAL_FLAG)) && !holders.length) {\n    result = createPartial(func, bitmask, thisArg, partials);\n  } else {\n    result = createHybrid.apply(undefined, newData);\n  }\n  return setWrapToString(result, func, bitmask);\n}\n\n/**\n * Gets the argument placeholder value for `func`.\n *\n * @private\n * @param {Function} func The function to inspect.\n * @returns {*} Returns the placeholder value.\n */\nfunction getHolder(func) {\n  var object = func;\n  return object.placeholder;\n}\n\n/**\n * Gets the native function at `key` of `object`.\n *\n * @private\n * @param {Object} object The object to query.\n * @param {string} key The key of the method to get.\n * @returns {*} Returns the function if it's native, else `undefined`.\n */\nfunction getNative(object, key) {\n  var value = getValue(object, key);\n  return baseIsNative(value) ? value : undefined;\n}\n\n/**\n * Extracts wrapper details from the `source` body comment.\n *\n * @private\n * @param {string} source The source to inspect.\n * @returns {Array} Returns the wrapper details.\n */\nfunction getWrapDetails(source) {\n  var match = source.match(reWrapDetails);\n  return match ? match[1].split(reSplitDetails) : [];\n}\n\n/**\n * Inserts wrapper `details` in a comment at the top of the `source` body.\n *\n * @private\n * @param {string} source The source to modify.\n * @returns {Array} details The details to insert.\n * @returns {string} Returns the modified source.\n */\nfunction insertWrapDetails(source, details) {\n  var length = details.length,\n      lastIndex = length - 1;\n\n  details[lastIndex] = (length > 1 ? '& ' : '') + details[lastIndex];\n  details = details.join(length > 2 ? ', ' : ' ');\n  return source.replace(reWrapComment, '{\\n/* [wrapped with ' + details + '] */\\n');\n}\n\n/**\n * Checks if `value` is a valid array-like index.\n *\n * @private\n * @param {*} value The value to check.\n * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.\n * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.\n */\nfunction isIndex(value, length) {\n  length = length == null ? MAX_SAFE_INTEGER : length;\n  return !!length &&\n    (typeof value == 'number' || reIsUint.test(value)) &&\n    (value > -1 && value % 1 == 0 && value < length);\n}\n\n/**\n * Checks if `func` has its source masked.\n *\n * @private\n * @param {Function} func The function to check.\n * @returns {boolean} Returns `true` if `func` is masked, else `false`.\n */\nfunction isMasked(func) {\n  return !!maskSrcKey && (maskSrcKey in func);\n}\n\n/**\n * Reorder `array` according to the specified indexes where the element at\n * the first index is assigned as the first element, the element at\n * the second index is assigned as the second element, and so on.\n *\n * @private\n * @param {Array} array The array to reorder.\n * @param {Array} indexes The arranged array indexes.\n * @returns {Array} Returns `array`.\n */\nfunction reorder(array, indexes) {\n  var arrLength = array.length,\n      length = nativeMin(indexes.length, arrLength),\n      oldArray = copyArray(array);\n\n  while (length--) {\n    var index = indexes[length];\n    array[length] = isIndex(index, arrLength) ? oldArray[index] : undefined;\n  }\n  return array;\n}\n\n/**\n * Sets the `toString` method of `wrapper` to mimic the source of `reference`\n * with wrapper details in a comment at the top of the source body.\n *\n * @private\n * @param {Function} wrapper The function to modify.\n * @param {Function} reference The reference function.\n * @param {number} bitmask The bitmask flags. See `createWrap` for more details.\n * @returns {Function} Returns `wrapper`.\n */\nvar setWrapToString = !defineProperty ? identity : function(wrapper, reference, bitmask) {\n  var source = (reference + '');\n  return defineProperty(wrapper, 'toString', {\n    'configurable': true,\n    'enumerable': false,\n    'value': constant(insertWrapDetails(source, updateWrapDetails(getWrapDetails(source), bitmask)))\n  });\n};\n\n/**\n * Converts `func` to its source code.\n *\n * @private\n * @param {Function} func The function to process.\n * @returns {string} Returns the source code.\n */\nfunction toSource(func) {\n  if (func != null) {\n    try {\n      return funcToString.call(func);\n    } catch (e) {}\n    try {\n      return (func + '');\n    } catch (e) {}\n  }\n  return '';\n}\n\n/**\n * Updates wrapper `details` based on `bitmask` flags.\n *\n * @private\n * @returns {Array} details The details to modify.\n * @param {number} bitmask The bitmask flags. See `createWrap` for more details.\n * @returns {Array} Returns `details`.\n */\nfunction updateWrapDetails(details, bitmask) {\n  arrayEach(wrapFlags, function(pair) {\n    var value = '_.' + pair[0];\n    if ((bitmask & pair[1]) && !arrayIncludes(details, value)) {\n      details.push(value);\n    }\n  });\n  return details.sort();\n}\n\n/**\n * Creates a function that accepts arguments of `func` and either invokes\n * `func` returning its result, if at least `arity` number of arguments have\n * been provided, or returns a function that accepts the remaining `func`\n * arguments, and so on. The arity of `func` may be specified if `func.length`\n * is not sufficient.\n *\n * The `_.curry.placeholder` value, which defaults to `_` in monolithic builds,\n * may be used as a placeholder for provided arguments.\n *\n * **Note:** This method doesn't set the \"length\" property of curried functions.\n *\n * @static\n * @memberOf _\n * @since 2.0.0\n * @category Function\n * @param {Function} func The function to curry.\n * @param {number} [arity=func.length] The arity of `func`.\n * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.\n * @returns {Function} Returns the new curried function.\n * @example\n *\n * var abc = function(a, b, c) {\n *   return [a, b, c];\n * };\n *\n * var curried = _.curry(abc);\n *\n * curried(1)(2)(3);\n * // => [1, 2, 3]\n *\n * curried(1, 2)(3);\n * // => [1, 2, 3]\n *\n * curried(1, 2, 3);\n * // => [1, 2, 3]\n *\n * // Curried with placeholders.\n * curried(1)(_, 3)(2);\n * // => [1, 2, 3]\n */\nfunction curry(func, arity, guard) {\n  arity = guard ? undefined : arity;\n  var result = createWrap(func, CURRY_FLAG, undefined, undefined, undefined, undefined, undefined, arity);\n  result.placeholder = curry.placeholder;\n  return result;\n}\n\n/**\n * Checks if `value` is classified as a `Function` object.\n *\n * @static\n * @memberOf _\n * @since 0.1.0\n * @category Lang\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is a function, else `false`.\n * @example\n *\n * _.isFunction(_);\n * // => true\n *\n * _.isFunction(/abc/);\n * // => false\n */\nfunction isFunction(value) {\n  // The use of `Object#toString` avoids issues with the `typeof` operator\n  // in Safari 8-9 which returns 'object' for typed array and other constructors.\n  var tag = isObject(value) ? objectToString.call(value) : '';\n  return tag == funcTag || tag == genTag;\n}\n\n/**\n * Checks if `value` is the\n * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)\n * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)\n *\n * @static\n * @memberOf _\n * @since 0.1.0\n * @category Lang\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is an object, else `false`.\n * @example\n *\n * _.isObject({});\n * // => true\n *\n * _.isObject([1, 2, 3]);\n * // => true\n *\n * _.isObject(_.noop);\n * // => true\n *\n * _.isObject(null);\n * // => false\n */\nfunction isObject(value) {\n  var type = typeof value;\n  return !!value && (type == 'object' || type == 'function');\n}\n\n/**\n * Checks if `value` is object-like. A value is object-like if it's not `null`\n * and has a `typeof` result of \"object\".\n *\n * @static\n * @memberOf _\n * @since 4.0.0\n * @category Lang\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is object-like, else `false`.\n * @example\n *\n * _.isObjectLike({});\n * // => true\n *\n * _.isObjectLike([1, 2, 3]);\n * // => true\n *\n * _.isObjectLike(_.noop);\n * // => false\n *\n * _.isObjectLike(null);\n * // => false\n */\nfunction isObjectLike(value) {\n  return !!value && typeof value == 'object';\n}\n\n/**\n * Checks if `value` is classified as a `Symbol` primitive or object.\n *\n * @static\n * @memberOf _\n * @since 4.0.0\n * @category Lang\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is a symbol, else `false`.\n * @example\n *\n * _.isSymbol(Symbol.iterator);\n * // => true\n *\n * _.isSymbol('abc');\n * // => false\n */\nfunction isSymbol(value) {\n  return typeof value == 'symbol' ||\n    (isObjectLike(value) && objectToString.call(value) == symbolTag);\n}\n\n/**\n * Converts `value` to a finite number.\n *\n * @static\n * @memberOf _\n * @since 4.12.0\n * @category Lang\n * @param {*} value The value to convert.\n * @returns {number} Returns the converted number.\n * @example\n *\n * _.toFinite(3.2);\n * // => 3.2\n *\n * _.toFinite(Number.MIN_VALUE);\n * // => 5e-324\n *\n * _.toFinite(Infinity);\n * // => 1.7976931348623157e+308\n *\n * _.toFinite('3.2');\n * // => 3.2\n */\nfunction toFinite(value) {\n  if (!value) {\n    return value === 0 ? value : 0;\n  }\n  value = toNumber(value);\n  if (value === INFINITY || value === -INFINITY) {\n    var sign = (value < 0 ? -1 : 1);\n    return sign * MAX_INTEGER;\n  }\n  return value === value ? value : 0;\n}\n\n/**\n * Converts `value` to an integer.\n *\n * **Note:** This method is loosely based on\n * [`ToInteger`](http://www.ecma-international.org/ecma-262/7.0/#sec-tointeger).\n *\n * @static\n * @memberOf _\n * @since 4.0.0\n * @category Lang\n * @param {*} value The value to convert.\n * @returns {number} Returns the converted integer.\n * @example\n *\n * _.toInteger(3.2);\n * // => 3\n *\n * _.toInteger(Number.MIN_VALUE);\n * // => 0\n *\n * _.toInteger(Infinity);\n * // => 1.7976931348623157e+308\n *\n * _.toInteger('3.2');\n * // => 3\n */\nfunction toInteger(value) {\n  var result = toFinite(value),\n      remainder = result % 1;\n\n  return result === result ? (remainder ? result - remainder : result) : 0;\n}\n\n/**\n * Converts `value` to a number.\n *\n * @static\n * @memberOf _\n * @since 4.0.0\n * @category Lang\n * @param {*} value The value to process.\n * @returns {number} Returns the number.\n * @example\n *\n * _.toNumber(3.2);\n * // => 3.2\n *\n * _.toNumber(Number.MIN_VALUE);\n * // => 5e-324\n *\n * _.toNumber(Infinity);\n * // => Infinity\n *\n * _.toNumber('3.2');\n * // => 3.2\n */\nfunction toNumber(value) {\n  if (typeof value == 'number') {\n    return value;\n  }\n  if (isSymbol(value)) {\n    return NAN;\n  }\n  if (isObject(value)) {\n    var other = typeof value.valueOf == 'function' ? value.valueOf() : value;\n    value = isObject(other) ? (other + '') : other;\n  }\n  if (typeof value != 'string') {\n    return value === 0 ? value : +value;\n  }\n  value = value.replace(reTrim, '');\n  var isBinary = reIsBinary.test(value);\n  return (isBinary || reIsOctal.test(value))\n    ? freeParseInt(value.slice(2), isBinary ? 2 : 8)\n    : (reIsBadHex.test(value) ? NAN : +value);\n}\n\n/**\n * Creates a function that returns `value`.\n *\n * @static\n * @memberOf _\n * @since 2.4.0\n * @category Util\n * @param {*} value The value to return from the new function.\n * @returns {Function} Returns the new constant function.\n * @example\n *\n * var objects = _.times(2, _.constant({ 'a': 1 }));\n *\n * console.log(objects);\n * // => [{ 'a': 1 }, { 'a': 1 }]\n *\n * console.log(objects[0] === objects[1]);\n * // => true\n */\nfunction constant(value) {\n  return function() {\n    return value;\n  };\n}\n\n/**\n * This method returns the first argument it receives.\n *\n * @static\n * @since 0.1.0\n * @memberOf _\n * @category Util\n * @param {*} value Any value.\n * @returns {*} Returns `value`.\n * @example\n *\n * var object = { 'a': 1 };\n *\n * console.log(_.identity(object) === object);\n * // => true\n */\nfunction identity(value) {\n  return value;\n}\n\n// Assign default placeholders.\ncurry.placeholder = {};\n\nmodule.exports = curry;\n\n/* WEBPACK VAR INJECTION */}.call(this, __webpack_require__(/*! ./../webpack/buildin/global.js */ \"../../node_modules/webpack/buildin/global.js\")))\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/lodash.curry/index.js?");

/***/ }),

/***/ "../../node_modules/lodash.flow/index.js":
/*!**********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/lodash.flow/index.js ***!
  \**********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("/* WEBPACK VAR INJECTION */(function(global) {/**\n * lodash (Custom Build) <https://lodash.com/>\n * Build: `lodash modularize exports=\"npm\" -o ./`\n * Copyright jQuery Foundation and other contributors <https://jquery.org/>\n * Released under MIT license <https://lodash.com/license>\n * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>\n * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors\n */\n\n/** Used as the `TypeError` message for \"Functions\" methods. */\nvar FUNC_ERROR_TEXT = 'Expected a function';\n\n/** Used as references for various `Number` constants. */\nvar MAX_SAFE_INTEGER = 9007199254740991;\n\n/** `Object#toString` result references. */\nvar argsTag = '[object Arguments]',\n    funcTag = '[object Function]',\n    genTag = '[object GeneratorFunction]';\n\n/** Detect free variable `global` from Node.js. */\nvar freeGlobal = typeof global == 'object' && global && global.Object === Object && global;\n\n/** Detect free variable `self`. */\nvar freeSelf = typeof self == 'object' && self && self.Object === Object && self;\n\n/** Used as a reference to the global object. */\nvar root = freeGlobal || freeSelf || Function('return this')();\n\n/**\n * A faster alternative to `Function#apply`, this function invokes `func`\n * with the `this` binding of `thisArg` and the arguments of `args`.\n *\n * @private\n * @param {Function} func The function to invoke.\n * @param {*} thisArg The `this` binding of `func`.\n * @param {Array} args The arguments to invoke `func` with.\n * @returns {*} Returns the result of `func`.\n */\nfunction apply(func, thisArg, args) {\n  switch (args.length) {\n    case 0: return func.call(thisArg);\n    case 1: return func.call(thisArg, args[0]);\n    case 2: return func.call(thisArg, args[0], args[1]);\n    case 3: return func.call(thisArg, args[0], args[1], args[2]);\n  }\n  return func.apply(thisArg, args);\n}\n\n/**\n * Appends the elements of `values` to `array`.\n *\n * @private\n * @param {Array} array The array to modify.\n * @param {Array} values The values to append.\n * @returns {Array} Returns `array`.\n */\nfunction arrayPush(array, values) {\n  var index = -1,\n      length = values.length,\n      offset = array.length;\n\n  while (++index < length) {\n    array[offset + index] = values[index];\n  }\n  return array;\n}\n\n/** Used for built-in method references. */\nvar objectProto = Object.prototype;\n\n/** Used to check objects for own properties. */\nvar hasOwnProperty = objectProto.hasOwnProperty;\n\n/**\n * Used to resolve the\n * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)\n * of values.\n */\nvar objectToString = objectProto.toString;\n\n/** Built-in value references. */\nvar Symbol = root.Symbol,\n    propertyIsEnumerable = objectProto.propertyIsEnumerable,\n    spreadableSymbol = Symbol ? Symbol.isConcatSpreadable : undefined;\n\n/* Built-in method references for those with the same name as other `lodash` methods. */\nvar nativeMax = Math.max;\n\n/**\n * The base implementation of `_.flatten` with support for restricting flattening.\n *\n * @private\n * @param {Array} array The array to flatten.\n * @param {number} depth The maximum recursion depth.\n * @param {boolean} [predicate=isFlattenable] The function invoked per iteration.\n * @param {boolean} [isStrict] Restrict to values that pass `predicate` checks.\n * @param {Array} [result=[]] The initial result value.\n * @returns {Array} Returns the new flattened array.\n */\nfunction baseFlatten(array, depth, predicate, isStrict, result) {\n  var index = -1,\n      length = array.length;\n\n  predicate || (predicate = isFlattenable);\n  result || (result = []);\n\n  while (++index < length) {\n    var value = array[index];\n    if (depth > 0 && predicate(value)) {\n      if (depth > 1) {\n        // Recursively flatten arrays (susceptible to call stack limits).\n        baseFlatten(value, depth - 1, predicate, isStrict, result);\n      } else {\n        arrayPush(result, value);\n      }\n    } else if (!isStrict) {\n      result[result.length] = value;\n    }\n  }\n  return result;\n}\n\n/**\n * The base implementation of `_.rest` which doesn't validate or coerce arguments.\n *\n * @private\n * @param {Function} func The function to apply a rest parameter to.\n * @param {number} [start=func.length-1] The start position of the rest parameter.\n * @returns {Function} Returns the new function.\n */\nfunction baseRest(func, start) {\n  start = nativeMax(start === undefined ? (func.length - 1) : start, 0);\n  return function() {\n    var args = arguments,\n        index = -1,\n        length = nativeMax(args.length - start, 0),\n        array = Array(length);\n\n    while (++index < length) {\n      array[index] = args[start + index];\n    }\n    index = -1;\n    var otherArgs = Array(start + 1);\n    while (++index < start) {\n      otherArgs[index] = args[index];\n    }\n    otherArgs[start] = array;\n    return apply(func, this, otherArgs);\n  };\n}\n\n/**\n * Creates a `_.flow` or `_.flowRight` function.\n *\n * @private\n * @param {boolean} [fromRight] Specify iterating from right to left.\n * @returns {Function} Returns the new flow function.\n */\nfunction createFlow(fromRight) {\n  return baseRest(function(funcs) {\n    funcs = baseFlatten(funcs, 1);\n\n    var length = funcs.length,\n        index = length;\n\n    if (fromRight) {\n      funcs.reverse();\n    }\n    while (index--) {\n      if (typeof funcs[index] != 'function') {\n        throw new TypeError(FUNC_ERROR_TEXT);\n      }\n    }\n    return function() {\n      var index = 0,\n          result = length ? funcs[index].apply(this, arguments) : arguments[0];\n\n      while (++index < length) {\n        result = funcs[index].call(this, result);\n      }\n      return result;\n    };\n  });\n}\n\n/**\n * Checks if `value` is a flattenable `arguments` object or array.\n *\n * @private\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is flattenable, else `false`.\n */\nfunction isFlattenable(value) {\n  return isArray(value) || isArguments(value) ||\n    !!(spreadableSymbol && value && value[spreadableSymbol]);\n}\n\n/**\n * Checks if `value` is likely an `arguments` object.\n *\n * @static\n * @memberOf _\n * @since 0.1.0\n * @category Lang\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is an `arguments` object,\n *  else `false`.\n * @example\n *\n * _.isArguments(function() { return arguments; }());\n * // => true\n *\n * _.isArguments([1, 2, 3]);\n * // => false\n */\nfunction isArguments(value) {\n  // Safari 8.1 makes `arguments.callee` enumerable in strict mode.\n  return isArrayLikeObject(value) && hasOwnProperty.call(value, 'callee') &&\n    (!propertyIsEnumerable.call(value, 'callee') || objectToString.call(value) == argsTag);\n}\n\n/**\n * Checks if `value` is classified as an `Array` object.\n *\n * @static\n * @memberOf _\n * @since 0.1.0\n * @category Lang\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is an array, else `false`.\n * @example\n *\n * _.isArray([1, 2, 3]);\n * // => true\n *\n * _.isArray(document.body.children);\n * // => false\n *\n * _.isArray('abc');\n * // => false\n *\n * _.isArray(_.noop);\n * // => false\n */\nvar isArray = Array.isArray;\n\n/**\n * Checks if `value` is array-like. A value is considered array-like if it's\n * not a function and has a `value.length` that's an integer greater than or\n * equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.\n *\n * @static\n * @memberOf _\n * @since 4.0.0\n * @category Lang\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is array-like, else `false`.\n * @example\n *\n * _.isArrayLike([1, 2, 3]);\n * // => true\n *\n * _.isArrayLike(document.body.children);\n * // => true\n *\n * _.isArrayLike('abc');\n * // => true\n *\n * _.isArrayLike(_.noop);\n * // => false\n */\nfunction isArrayLike(value) {\n  return value != null && isLength(value.length) && !isFunction(value);\n}\n\n/**\n * This method is like `_.isArrayLike` except that it also checks if `value`\n * is an object.\n *\n * @static\n * @memberOf _\n * @since 4.0.0\n * @category Lang\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is an array-like object,\n *  else `false`.\n * @example\n *\n * _.isArrayLikeObject([1, 2, 3]);\n * // => true\n *\n * _.isArrayLikeObject(document.body.children);\n * // => true\n *\n * _.isArrayLikeObject('abc');\n * // => false\n *\n * _.isArrayLikeObject(_.noop);\n * // => false\n */\nfunction isArrayLikeObject(value) {\n  return isObjectLike(value) && isArrayLike(value);\n}\n\n/**\n * Checks if `value` is classified as a `Function` object.\n *\n * @static\n * @memberOf _\n * @since 0.1.0\n * @category Lang\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is a function, else `false`.\n * @example\n *\n * _.isFunction(_);\n * // => true\n *\n * _.isFunction(/abc/);\n * // => false\n */\nfunction isFunction(value) {\n  // The use of `Object#toString` avoids issues with the `typeof` operator\n  // in Safari 8-9 which returns 'object' for typed array and other constructors.\n  var tag = isObject(value) ? objectToString.call(value) : '';\n  return tag == funcTag || tag == genTag;\n}\n\n/**\n * Checks if `value` is a valid array-like length.\n *\n * **Note:** This method is loosely based on\n * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).\n *\n * @static\n * @memberOf _\n * @since 4.0.0\n * @category Lang\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is a valid length, else `false`.\n * @example\n *\n * _.isLength(3);\n * // => true\n *\n * _.isLength(Number.MIN_VALUE);\n * // => false\n *\n * _.isLength(Infinity);\n * // => false\n *\n * _.isLength('3');\n * // => false\n */\nfunction isLength(value) {\n  return typeof value == 'number' &&\n    value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;\n}\n\n/**\n * Checks if `value` is the\n * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)\n * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)\n *\n * @static\n * @memberOf _\n * @since 0.1.0\n * @category Lang\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is an object, else `false`.\n * @example\n *\n * _.isObject({});\n * // => true\n *\n * _.isObject([1, 2, 3]);\n * // => true\n *\n * _.isObject(_.noop);\n * // => true\n *\n * _.isObject(null);\n * // => false\n */\nfunction isObject(value) {\n  var type = typeof value;\n  return !!value && (type == 'object' || type == 'function');\n}\n\n/**\n * Checks if `value` is object-like. A value is object-like if it's not `null`\n * and has a `typeof` result of \"object\".\n *\n * @static\n * @memberOf _\n * @since 4.0.0\n * @category Lang\n * @param {*} value The value to check.\n * @returns {boolean} Returns `true` if `value` is object-like, else `false`.\n * @example\n *\n * _.isObjectLike({});\n * // => true\n *\n * _.isObjectLike([1, 2, 3]);\n * // => true\n *\n * _.isObjectLike(_.noop);\n * // => false\n *\n * _.isObjectLike(null);\n * // => false\n */\nfunction isObjectLike(value) {\n  return !!value && typeof value == 'object';\n}\n\n/**\n * Creates a function that returns the result of invoking the given functions\n * with the `this` binding of the created function, where each successive\n * invocation is supplied the return value of the previous.\n *\n * @static\n * @memberOf _\n * @since 3.0.0\n * @category Util\n * @param {...(Function|Function[])} [funcs] The functions to invoke.\n * @returns {Function} Returns the new composite function.\n * @see _.flowRight\n * @example\n *\n * function square(n) {\n *   return n * n;\n * }\n *\n * var addSquare = _.flow([_.add, square]);\n * addSquare(1, 2);\n * // => 9\n */\nvar flow = createFlow();\n\nmodule.exports = flow;\n\n/* WEBPACK VAR INJECTION */}.call(this, __webpack_require__(/*! ./../webpack/buildin/global.js */ \"../../node_modules/webpack/buildin/global.js\")))\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/lodash.flow/index.js?");

/***/ }),

/***/ "../../node_modules/object-assign/index.js":
/*!************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/object-assign/index.js ***!
  \************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("/*\nobject-assign\n(c) Sindre Sorhus\n@license MIT\n*/\n\n\n/* eslint-disable no-unused-vars */\nvar getOwnPropertySymbols = Object.getOwnPropertySymbols;\nvar hasOwnProperty = Object.prototype.hasOwnProperty;\nvar propIsEnumerable = Object.prototype.propertyIsEnumerable;\n\nfunction toObject(val) {\n\tif (val === null || val === undefined) {\n\t\tthrow new TypeError('Object.assign cannot be called with null or undefined');\n\t}\n\n\treturn Object(val);\n}\n\nfunction shouldUseNative() {\n\ttry {\n\t\tif (!Object.assign) {\n\t\t\treturn false;\n\t\t}\n\n\t\t// Detect buggy property enumeration order in older V8 versions.\n\n\t\t// https://bugs.chromium.org/p/v8/issues/detail?id=4118\n\t\tvar test1 = new String('abc');  // eslint-disable-line no-new-wrappers\n\t\ttest1[5] = 'de';\n\t\tif (Object.getOwnPropertyNames(test1)[0] === '5') {\n\t\t\treturn false;\n\t\t}\n\n\t\t// https://bugs.chromium.org/p/v8/issues/detail?id=3056\n\t\tvar test2 = {};\n\t\tfor (var i = 0; i < 10; i++) {\n\t\t\ttest2['_' + String.fromCharCode(i)] = i;\n\t\t}\n\t\tvar order2 = Object.getOwnPropertyNames(test2).map(function (n) {\n\t\t\treturn test2[n];\n\t\t});\n\t\tif (order2.join('') !== '0123456789') {\n\t\t\treturn false;\n\t\t}\n\n\t\t// https://bugs.chromium.org/p/v8/issues/detail?id=3056\n\t\tvar test3 = {};\n\t\t'abcdefghijklmnopqrst'.split('').forEach(function (letter) {\n\t\t\ttest3[letter] = letter;\n\t\t});\n\t\tif (Object.keys(Object.assign({}, test3)).join('') !==\n\t\t\t\t'abcdefghijklmnopqrst') {\n\t\t\treturn false;\n\t\t}\n\n\t\treturn true;\n\t} catch (err) {\n\t\t// We don't expect any of the above to throw, but better to be safe.\n\t\treturn false;\n\t}\n}\n\nmodule.exports = shouldUseNative() ? Object.assign : function (target, source) {\n\tvar from;\n\tvar to = toObject(target);\n\tvar symbols;\n\n\tfor (var s = 1; s < arguments.length; s++) {\n\t\tfrom = Object(arguments[s]);\n\n\t\tfor (var key in from) {\n\t\t\tif (hasOwnProperty.call(from, key)) {\n\t\t\t\tto[key] = from[key];\n\t\t\t}\n\t\t}\n\n\t\tif (getOwnPropertySymbols) {\n\t\t\tsymbols = getOwnPropertySymbols(from);\n\t\t\tfor (var i = 0; i < symbols.length; i++) {\n\t\t\t\tif (propIsEnumerable.call(from, symbols[i])) {\n\t\t\t\t\tto[symbols[i]] = from[symbols[i]];\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\t}\n\n\treturn to;\n};\n\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/object-assign/index.js?");

/***/ }),

/***/ "../../node_modules/prop-types/checkPropTypes.js":
/*!******************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/prop-types/checkPropTypes.js ***!
  \******************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("/**\n * Copyright (c) 2013-present, Facebook, Inc.\n *\n * This source code is licensed under the MIT license found in the\n * LICENSE file in the root directory of this source tree.\n */\n\n\n\nvar printWarning = function() {};\n\nif (true) {\n  var ReactPropTypesSecret = __webpack_require__(/*! ./lib/ReactPropTypesSecret */ \"../../node_modules/prop-types/lib/ReactPropTypesSecret.js\");\n  var loggedTypeFailures = {};\n  var has = Function.call.bind(Object.prototype.hasOwnProperty);\n\n  printWarning = function(text) {\n    var message = 'Warning: ' + text;\n    if (typeof console !== 'undefined') {\n      console.error(message);\n    }\n    try {\n      // --- Welcome to debugging React ---\n      // This error was thrown as a convenience so that you can use this stack\n      // to find the callsite that caused this warning to fire.\n      throw new Error(message);\n    } catch (x) {}\n  };\n}\n\n/**\n * Assert that the values match with the type specs.\n * Error messages are memorized and will only be shown once.\n *\n * @param {object} typeSpecs Map of name to a ReactPropType\n * @param {object} values Runtime values that need to be type-checked\n * @param {string} location e.g. \"prop\", \"context\", \"child context\"\n * @param {string} componentName Name of the component for error messages.\n * @param {?Function} getStack Returns the component stack.\n * @private\n */\nfunction checkPropTypes(typeSpecs, values, location, componentName, getStack) {\n  if (true) {\n    for (var typeSpecName in typeSpecs) {\n      if (has(typeSpecs, typeSpecName)) {\n        var error;\n        // Prop type validation may throw. In case they do, we don't want to\n        // fail the render phase where it didn't fail before. So we log it.\n        // After these have been cleaned up, we'll let them throw.\n        try {\n          // This is intentionally an invariant that gets caught. It's the same\n          // behavior as without this statement except with a better message.\n          if (typeof typeSpecs[typeSpecName] !== 'function') {\n            var err = Error(\n              (componentName || 'React class') + ': ' + location + ' type `' + typeSpecName + '` is invalid; ' +\n              'it must be a function, usually from the `prop-types` package, but received `' + typeof typeSpecs[typeSpecName] + '`.'\n            );\n            err.name = 'Invariant Violation';\n            throw err;\n          }\n          error = typeSpecs[typeSpecName](values, typeSpecName, componentName, location, null, ReactPropTypesSecret);\n        } catch (ex) {\n          error = ex;\n        }\n        if (error && !(error instanceof Error)) {\n          printWarning(\n            (componentName || 'React class') + ': type specification of ' +\n            location + ' `' + typeSpecName + '` is invalid; the type checker ' +\n            'function must return `null` or an `Error` but returned a ' + typeof error + '. ' +\n            'You may have forgotten to pass an argument to the type checker ' +\n            'creator (arrayOf, instanceOf, objectOf, oneOf, oneOfType, and ' +\n            'shape all require an argument).'\n          );\n        }\n        if (error instanceof Error && !(error.message in loggedTypeFailures)) {\n          // Only monitor this failure once because there tends to be a lot of the\n          // same error.\n          loggedTypeFailures[error.message] = true;\n\n          var stack = getStack ? getStack() : '';\n\n          printWarning(\n            'Failed ' + location + ' type: ' + error.message + (stack != null ? stack : '')\n          );\n        }\n      }\n    }\n  }\n}\n\n/**\n * Resets warning cache when testing.\n *\n * @private\n */\ncheckPropTypes.resetWarningCache = function() {\n  if (true) {\n    loggedTypeFailures = {};\n  }\n}\n\nmodule.exports = checkPropTypes;\n\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/prop-types/checkPropTypes.js?");

/***/ }),

/***/ "../../node_modules/prop-types/factoryWithTypeCheckers.js":
/*!***************************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/prop-types/factoryWithTypeCheckers.js ***!
  \***************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("/**\n * Copyright (c) 2013-present, Facebook, Inc.\n *\n * This source code is licensed under the MIT license found in the\n * LICENSE file in the root directory of this source tree.\n */\n\n\n\nvar ReactIs = __webpack_require__(/*! react-is */ \"../../node_modules/react-is/index.js\");\nvar assign = __webpack_require__(/*! object-assign */ \"../../node_modules/object-assign/index.js\");\n\nvar ReactPropTypesSecret = __webpack_require__(/*! ./lib/ReactPropTypesSecret */ \"../../node_modules/prop-types/lib/ReactPropTypesSecret.js\");\nvar checkPropTypes = __webpack_require__(/*! ./checkPropTypes */ \"../../node_modules/prop-types/checkPropTypes.js\");\n\nvar has = Function.call.bind(Object.prototype.hasOwnProperty);\nvar printWarning = function() {};\n\nif (true) {\n  printWarning = function(text) {\n    var message = 'Warning: ' + text;\n    if (typeof console !== 'undefined') {\n      console.error(message);\n    }\n    try {\n      // --- Welcome to debugging React ---\n      // This error was thrown as a convenience so that you can use this stack\n      // to find the callsite that caused this warning to fire.\n      throw new Error(message);\n    } catch (x) {}\n  };\n}\n\nfunction emptyFunctionThatReturnsNull() {\n  return null;\n}\n\nmodule.exports = function(isValidElement, throwOnDirectAccess) {\n  /* global Symbol */\n  var ITERATOR_SYMBOL = typeof Symbol === 'function' && Symbol.iterator;\n  var FAUX_ITERATOR_SYMBOL = '@@iterator'; // Before Symbol spec.\n\n  /**\n   * Returns the iterator method function contained on the iterable object.\n   *\n   * Be sure to invoke the function with the iterable as context:\n   *\n   *     var iteratorFn = getIteratorFn(myIterable);\n   *     if (iteratorFn) {\n   *       var iterator = iteratorFn.call(myIterable);\n   *       ...\n   *     }\n   *\n   * @param {?object} maybeIterable\n   * @return {?function}\n   */\n  function getIteratorFn(maybeIterable) {\n    var iteratorFn = maybeIterable && (ITERATOR_SYMBOL && maybeIterable[ITERATOR_SYMBOL] || maybeIterable[FAUX_ITERATOR_SYMBOL]);\n    if (typeof iteratorFn === 'function') {\n      return iteratorFn;\n    }\n  }\n\n  /**\n   * Collection of methods that allow declaration and validation of props that are\n   * supplied to React components. Example usage:\n   *\n   *   var Props = require('ReactPropTypes');\n   *   var MyArticle = React.createClass({\n   *     propTypes: {\n   *       // An optional string prop named \"description\".\n   *       description: Props.string,\n   *\n   *       // A required enum prop named \"category\".\n   *       category: Props.oneOf(['News','Photos']).isRequired,\n   *\n   *       // A prop named \"dialog\" that requires an instance of Dialog.\n   *       dialog: Props.instanceOf(Dialog).isRequired\n   *     },\n   *     render: function() { ... }\n   *   });\n   *\n   * A more formal specification of how these methods are used:\n   *\n   *   type := array|bool|func|object|number|string|oneOf([...])|instanceOf(...)\n   *   decl := ReactPropTypes.{type}(.isRequired)?\n   *\n   * Each and every declaration produces a function with the same signature. This\n   * allows the creation of custom validation functions. For example:\n   *\n   *  var MyLink = React.createClass({\n   *    propTypes: {\n   *      // An optional string or URI prop named \"href\".\n   *      href: function(props, propName, componentName) {\n   *        var propValue = props[propName];\n   *        if (propValue != null && typeof propValue !== 'string' &&\n   *            !(propValue instanceof URI)) {\n   *          return new Error(\n   *            'Expected a string or an URI for ' + propName + ' in ' +\n   *            componentName\n   *          );\n   *        }\n   *      }\n   *    },\n   *    render: function() {...}\n   *  });\n   *\n   * @internal\n   */\n\n  var ANONYMOUS = '<<anonymous>>';\n\n  // Important!\n  // Keep this list in sync with production version in `./factoryWithThrowingShims.js`.\n  var ReactPropTypes = {\n    array: createPrimitiveTypeChecker('array'),\n    bool: createPrimitiveTypeChecker('boolean'),\n    func: createPrimitiveTypeChecker('function'),\n    number: createPrimitiveTypeChecker('number'),\n    object: createPrimitiveTypeChecker('object'),\n    string: createPrimitiveTypeChecker('string'),\n    symbol: createPrimitiveTypeChecker('symbol'),\n\n    any: createAnyTypeChecker(),\n    arrayOf: createArrayOfTypeChecker,\n    element: createElementTypeChecker(),\n    elementType: createElementTypeTypeChecker(),\n    instanceOf: createInstanceTypeChecker,\n    node: createNodeChecker(),\n    objectOf: createObjectOfTypeChecker,\n    oneOf: createEnumTypeChecker,\n    oneOfType: createUnionTypeChecker,\n    shape: createShapeTypeChecker,\n    exact: createStrictShapeTypeChecker,\n  };\n\n  /**\n   * inlined Object.is polyfill to avoid requiring consumers ship their own\n   * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/is\n   */\n  /*eslint-disable no-self-compare*/\n  function is(x, y) {\n    // SameValue algorithm\n    if (x === y) {\n      // Steps 1-5, 7-10\n      // Steps 6.b-6.e: +0 != -0\n      return x !== 0 || 1 / x === 1 / y;\n    } else {\n      // Step 6.a: NaN == NaN\n      return x !== x && y !== y;\n    }\n  }\n  /*eslint-enable no-self-compare*/\n\n  /**\n   * We use an Error-like object for backward compatibility as people may call\n   * PropTypes directly and inspect their output. However, we don't use real\n   * Errors anymore. We don't inspect their stack anyway, and creating them\n   * is prohibitively expensive if they are created too often, such as what\n   * happens in oneOfType() for any type before the one that matched.\n   */\n  function PropTypeError(message) {\n    this.message = message;\n    this.stack = '';\n  }\n  // Make `instanceof Error` still work for returned errors.\n  PropTypeError.prototype = Error.prototype;\n\n  function createChainableTypeChecker(validate) {\n    if (true) {\n      var manualPropTypeCallCache = {};\n      var manualPropTypeWarningCount = 0;\n    }\n    function checkType(isRequired, props, propName, componentName, location, propFullName, secret) {\n      componentName = componentName || ANONYMOUS;\n      propFullName = propFullName || propName;\n\n      if (secret !== ReactPropTypesSecret) {\n        if (throwOnDirectAccess) {\n          // New behavior only for users of `prop-types` package\n          var err = new Error(\n            'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +\n            'Use `PropTypes.checkPropTypes()` to call them. ' +\n            'Read more at http://fb.me/use-check-prop-types'\n          );\n          err.name = 'Invariant Violation';\n          throw err;\n        } else if ( true && typeof console !== 'undefined') {\n          // Old behavior for people using React.PropTypes\n          var cacheKey = componentName + ':' + propName;\n          if (\n            !manualPropTypeCallCache[cacheKey] &&\n            // Avoid spamming the console because they are often not actionable except for lib authors\n            manualPropTypeWarningCount < 3\n          ) {\n            printWarning(\n              'You are manually calling a React.PropTypes validation ' +\n              'function for the `' + propFullName + '` prop on `' + componentName  + '`. This is deprecated ' +\n              'and will throw in the standalone `prop-types` package. ' +\n              'You may be seeing this warning due to a third-party PropTypes ' +\n              'library. See https://fb.me/react-warning-dont-call-proptypes ' + 'for details.'\n            );\n            manualPropTypeCallCache[cacheKey] = true;\n            manualPropTypeWarningCount++;\n          }\n        }\n      }\n      if (props[propName] == null) {\n        if (isRequired) {\n          if (props[propName] === null) {\n            return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required ' + ('in `' + componentName + '`, but its value is `null`.'));\n          }\n          return new PropTypeError('The ' + location + ' `' + propFullName + '` is marked as required in ' + ('`' + componentName + '`, but its value is `undefined`.'));\n        }\n        return null;\n      } else {\n        return validate(props, propName, componentName, location, propFullName);\n      }\n    }\n\n    var chainedCheckType = checkType.bind(null, false);\n    chainedCheckType.isRequired = checkType.bind(null, true);\n\n    return chainedCheckType;\n  }\n\n  function createPrimitiveTypeChecker(expectedType) {\n    function validate(props, propName, componentName, location, propFullName, secret) {\n      var propValue = props[propName];\n      var propType = getPropType(propValue);\n      if (propType !== expectedType) {\n        // `propValue` being instance of, say, date/regexp, pass the 'object'\n        // check, but we can offer a more precise error message here rather than\n        // 'of type `object`'.\n        var preciseType = getPreciseType(propValue);\n\n        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + preciseType + '` supplied to `' + componentName + '`, expected ') + ('`' + expectedType + '`.'));\n      }\n      return null;\n    }\n    return createChainableTypeChecker(validate);\n  }\n\n  function createAnyTypeChecker() {\n    return createChainableTypeChecker(emptyFunctionThatReturnsNull);\n  }\n\n  function createArrayOfTypeChecker(typeChecker) {\n    function validate(props, propName, componentName, location, propFullName) {\n      if (typeof typeChecker !== 'function') {\n        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside arrayOf.');\n      }\n      var propValue = props[propName];\n      if (!Array.isArray(propValue)) {\n        var propType = getPropType(propValue);\n        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an array.'));\n      }\n      for (var i = 0; i < propValue.length; i++) {\n        var error = typeChecker(propValue, i, componentName, location, propFullName + '[' + i + ']', ReactPropTypesSecret);\n        if (error instanceof Error) {\n          return error;\n        }\n      }\n      return null;\n    }\n    return createChainableTypeChecker(validate);\n  }\n\n  function createElementTypeChecker() {\n    function validate(props, propName, componentName, location, propFullName) {\n      var propValue = props[propName];\n      if (!isValidElement(propValue)) {\n        var propType = getPropType(propValue);\n        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement.'));\n      }\n      return null;\n    }\n    return createChainableTypeChecker(validate);\n  }\n\n  function createElementTypeTypeChecker() {\n    function validate(props, propName, componentName, location, propFullName) {\n      var propValue = props[propName];\n      if (!ReactIs.isValidElementType(propValue)) {\n        var propType = getPropType(propValue);\n        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected a single ReactElement type.'));\n      }\n      return null;\n    }\n    return createChainableTypeChecker(validate);\n  }\n\n  function createInstanceTypeChecker(expectedClass) {\n    function validate(props, propName, componentName, location, propFullName) {\n      if (!(props[propName] instanceof expectedClass)) {\n        var expectedClassName = expectedClass.name || ANONYMOUS;\n        var actualClassName = getClassName(props[propName]);\n        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + actualClassName + '` supplied to `' + componentName + '`, expected ') + ('instance of `' + expectedClassName + '`.'));\n      }\n      return null;\n    }\n    return createChainableTypeChecker(validate);\n  }\n\n  function createEnumTypeChecker(expectedValues) {\n    if (!Array.isArray(expectedValues)) {\n      if (true) {\n        if (arguments.length > 1) {\n          printWarning(\n            'Invalid arguments supplied to oneOf, expected an array, got ' + arguments.length + ' arguments. ' +\n            'A common mistake is to write oneOf(x, y, z) instead of oneOf([x, y, z]).'\n          );\n        } else {\n          printWarning('Invalid argument supplied to oneOf, expected an array.');\n        }\n      }\n      return emptyFunctionThatReturnsNull;\n    }\n\n    function validate(props, propName, componentName, location, propFullName) {\n      var propValue = props[propName];\n      for (var i = 0; i < expectedValues.length; i++) {\n        if (is(propValue, expectedValues[i])) {\n          return null;\n        }\n      }\n\n      var valuesString = JSON.stringify(expectedValues, function replacer(key, value) {\n        var type = getPreciseType(value);\n        if (type === 'symbol') {\n          return String(value);\n        }\n        return value;\n      });\n      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of value `' + String(propValue) + '` ' + ('supplied to `' + componentName + '`, expected one of ' + valuesString + '.'));\n    }\n    return createChainableTypeChecker(validate);\n  }\n\n  function createObjectOfTypeChecker(typeChecker) {\n    function validate(props, propName, componentName, location, propFullName) {\n      if (typeof typeChecker !== 'function') {\n        return new PropTypeError('Property `' + propFullName + '` of component `' + componentName + '` has invalid PropType notation inside objectOf.');\n      }\n      var propValue = props[propName];\n      var propType = getPropType(propValue);\n      if (propType !== 'object') {\n        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type ' + ('`' + propType + '` supplied to `' + componentName + '`, expected an object.'));\n      }\n      for (var key in propValue) {\n        if (has(propValue, key)) {\n          var error = typeChecker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret);\n          if (error instanceof Error) {\n            return error;\n          }\n        }\n      }\n      return null;\n    }\n    return createChainableTypeChecker(validate);\n  }\n\n  function createUnionTypeChecker(arrayOfTypeCheckers) {\n    if (!Array.isArray(arrayOfTypeCheckers)) {\n       true ? printWarning('Invalid argument supplied to oneOfType, expected an instance of array.') : undefined;\n      return emptyFunctionThatReturnsNull;\n    }\n\n    for (var i = 0; i < arrayOfTypeCheckers.length; i++) {\n      var checker = arrayOfTypeCheckers[i];\n      if (typeof checker !== 'function') {\n        printWarning(\n          'Invalid argument supplied to oneOfType. Expected an array of check functions, but ' +\n          'received ' + getPostfixForTypeWarning(checker) + ' at index ' + i + '.'\n        );\n        return emptyFunctionThatReturnsNull;\n      }\n    }\n\n    function validate(props, propName, componentName, location, propFullName) {\n      for (var i = 0; i < arrayOfTypeCheckers.length; i++) {\n        var checker = arrayOfTypeCheckers[i];\n        if (checker(props, propName, componentName, location, propFullName, ReactPropTypesSecret) == null) {\n          return null;\n        }\n      }\n\n      return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`.'));\n    }\n    return createChainableTypeChecker(validate);\n  }\n\n  function createNodeChecker() {\n    function validate(props, propName, componentName, location, propFullName) {\n      if (!isNode(props[propName])) {\n        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` supplied to ' + ('`' + componentName + '`, expected a ReactNode.'));\n      }\n      return null;\n    }\n    return createChainableTypeChecker(validate);\n  }\n\n  function createShapeTypeChecker(shapeTypes) {\n    function validate(props, propName, componentName, location, propFullName) {\n      var propValue = props[propName];\n      var propType = getPropType(propValue);\n      if (propType !== 'object') {\n        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));\n      }\n      for (var key in shapeTypes) {\n        var checker = shapeTypes[key];\n        if (!checker) {\n          continue;\n        }\n        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret);\n        if (error) {\n          return error;\n        }\n      }\n      return null;\n    }\n    return createChainableTypeChecker(validate);\n  }\n\n  function createStrictShapeTypeChecker(shapeTypes) {\n    function validate(props, propName, componentName, location, propFullName) {\n      var propValue = props[propName];\n      var propType = getPropType(propValue);\n      if (propType !== 'object') {\n        return new PropTypeError('Invalid ' + location + ' `' + propFullName + '` of type `' + propType + '` ' + ('supplied to `' + componentName + '`, expected `object`.'));\n      }\n      // We need to check all keys in case some are required but missing from\n      // props.\n      var allKeys = assign({}, props[propName], shapeTypes);\n      for (var key in allKeys) {\n        var checker = shapeTypes[key];\n        if (!checker) {\n          return new PropTypeError(\n            'Invalid ' + location + ' `' + propFullName + '` key `' + key + '` supplied to `' + componentName + '`.' +\n            '\\nBad object: ' + JSON.stringify(props[propName], null, '  ') +\n            '\\nValid keys: ' +  JSON.stringify(Object.keys(shapeTypes), null, '  ')\n          );\n        }\n        var error = checker(propValue, key, componentName, location, propFullName + '.' + key, ReactPropTypesSecret);\n        if (error) {\n          return error;\n        }\n      }\n      return null;\n    }\n\n    return createChainableTypeChecker(validate);\n  }\n\n  function isNode(propValue) {\n    switch (typeof propValue) {\n      case 'number':\n      case 'string':\n      case 'undefined':\n        return true;\n      case 'boolean':\n        return !propValue;\n      case 'object':\n        if (Array.isArray(propValue)) {\n          return propValue.every(isNode);\n        }\n        if (propValue === null || isValidElement(propValue)) {\n          return true;\n        }\n\n        var iteratorFn = getIteratorFn(propValue);\n        if (iteratorFn) {\n          var iterator = iteratorFn.call(propValue);\n          var step;\n          if (iteratorFn !== propValue.entries) {\n            while (!(step = iterator.next()).done) {\n              if (!isNode(step.value)) {\n                return false;\n              }\n            }\n          } else {\n            // Iterator will provide entry [k,v] tuples rather than values.\n            while (!(step = iterator.next()).done) {\n              var entry = step.value;\n              if (entry) {\n                if (!isNode(entry[1])) {\n                  return false;\n                }\n              }\n            }\n          }\n        } else {\n          return false;\n        }\n\n        return true;\n      default:\n        return false;\n    }\n  }\n\n  function isSymbol(propType, propValue) {\n    // Native Symbol.\n    if (propType === 'symbol') {\n      return true;\n    }\n\n    // falsy value can't be a Symbol\n    if (!propValue) {\n      return false;\n    }\n\n    // 19.4.3.5 Symbol.prototype[@@toStringTag] === 'Symbol'\n    if (propValue['@@toStringTag'] === 'Symbol') {\n      return true;\n    }\n\n    // Fallback for non-spec compliant Symbols which are polyfilled.\n    if (typeof Symbol === 'function' && propValue instanceof Symbol) {\n      return true;\n    }\n\n    return false;\n  }\n\n  // Equivalent of `typeof` but with special handling for array and regexp.\n  function getPropType(propValue) {\n    var propType = typeof propValue;\n    if (Array.isArray(propValue)) {\n      return 'array';\n    }\n    if (propValue instanceof RegExp) {\n      // Old webkits (at least until Android 4.0) return 'function' rather than\n      // 'object' for typeof a RegExp. We'll normalize this here so that /bla/\n      // passes PropTypes.object.\n      return 'object';\n    }\n    if (isSymbol(propType, propValue)) {\n      return 'symbol';\n    }\n    return propType;\n  }\n\n  // This handles more types than `getPropType`. Only used for error messages.\n  // See `createPrimitiveTypeChecker`.\n  function getPreciseType(propValue) {\n    if (typeof propValue === 'undefined' || propValue === null) {\n      return '' + propValue;\n    }\n    var propType = getPropType(propValue);\n    if (propType === 'object') {\n      if (propValue instanceof Date) {\n        return 'date';\n      } else if (propValue instanceof RegExp) {\n        return 'regexp';\n      }\n    }\n    return propType;\n  }\n\n  // Returns a string that is postfixed to a warning about an invalid type.\n  // For example, \"undefined\" or \"of type array\"\n  function getPostfixForTypeWarning(value) {\n    var type = getPreciseType(value);\n    switch (type) {\n      case 'array':\n      case 'object':\n        return 'an ' + type;\n      case 'boolean':\n      case 'date':\n      case 'regexp':\n        return 'a ' + type;\n      default:\n        return type;\n    }\n  }\n\n  // Returns class name of the object, if any.\n  function getClassName(propValue) {\n    if (!propValue.constructor || !propValue.constructor.name) {\n      return ANONYMOUS;\n    }\n    return propValue.constructor.name;\n  }\n\n  ReactPropTypes.checkPropTypes = checkPropTypes;\n  ReactPropTypes.resetWarningCache = checkPropTypes.resetWarningCache;\n  ReactPropTypes.PropTypes = ReactPropTypes;\n\n  return ReactPropTypes;\n};\n\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/prop-types/factoryWithTypeCheckers.js?");

/***/ }),

/***/ "../../node_modules/prop-types/index.js":
/*!*********************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/prop-types/index.js ***!
  \*********************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("/**\n * Copyright (c) 2013-present, Facebook, Inc.\n *\n * This source code is licensed under the MIT license found in the\n * LICENSE file in the root directory of this source tree.\n */\n\nif (true) {\n  var ReactIs = __webpack_require__(/*! react-is */ \"../../node_modules/react-is/index.js\");\n\n  // By explicitly using `prop-types` you are opting into new development behavior.\n  // http://fb.me/prop-types-in-prod\n  var throwOnDirectAccess = true;\n  module.exports = __webpack_require__(/*! ./factoryWithTypeCheckers */ \"../../node_modules/prop-types/factoryWithTypeCheckers.js\")(ReactIs.isElement, throwOnDirectAccess);\n} else {}\n\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/prop-types/index.js?");

/***/ }),

/***/ "../../node_modules/prop-types/lib/ReactPropTypesSecret.js":
/*!****************************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/prop-types/lib/ReactPropTypesSecret.js ***!
  \****************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("/**\n * Copyright (c) 2013-present, Facebook, Inc.\n *\n * This source code is licensed under the MIT license found in the\n * LICENSE file in the root directory of this source tree.\n */\n\n\n\nvar ReactPropTypesSecret = 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED';\n\nmodule.exports = ReactPropTypesSecret;\n\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/prop-types/lib/ReactPropTypesSecret.js?");

/***/ }),

/***/ "../../node_modules/pure-color/convert/hsl2rgb.js":
/*!*******************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/convert/hsl2rgb.js ***!
  \*******************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports) {

eval("function hsl2rgb(hsl) {\n  var h = hsl[0] / 360,\n      s = hsl[1] / 100,\n      l = hsl[2] / 100,\n      t1, t2, t3, rgb, val;\n\n  if (s == 0) {\n    val = l * 255;\n    return [val, val, val];\n  }\n\n  if (l < 0.5)\n    t2 = l * (1 + s);\n  else\n    t2 = l + s - l * s;\n  t1 = 2 * l - t2;\n\n  rgb = [0, 0, 0];\n  for (var i = 0; i < 3; i++) {\n    t3 = h + 1 / 3 * - (i - 1);\n    t3 < 0 && t3++;\n    t3 > 1 && t3--;\n\n    if (6 * t3 < 1)\n      val = t1 + (t2 - t1) * 6 * t3;\n    else if (2 * t3 < 1)\n      val = t2;\n    else if (3 * t3 < 2)\n      val = t1 + (t2 - t1) * (2 / 3 - t3) * 6;\n    else\n      val = t1;\n\n    rgb[i] = val * 255;\n  }\n\n  return rgb;\n}\n\nmodule.exports = hsl2rgb;\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/convert/hsl2rgb.js?");

/***/ }),

/***/ "../../node_modules/pure-color/convert/rgb2hex.js":
/*!*******************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/convert/rgb2hex.js ***!
  \*******************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("var clamp = __webpack_require__(/*! ../util/clamp */ \"../../node_modules/pure-color/util/clamp.js\");\n\nfunction componentToHex(c) {\n  var value = Math.round(clamp(c, 0, 255));\n  var hex   = value.toString(16);\n\n  return hex.length == 1 ? \"0\" + hex : hex;\n}\n\nfunction rgb2hex(rgb) {\n  var alpha = rgb.length === 4 ? componentToHex(rgb[3] * 255) : \"\";\n\n  return \"#\" + componentToHex(rgb[0]) + componentToHex(rgb[1]) + componentToHex(rgb[2]) + alpha;\n}\n\nmodule.exports = rgb2hex;\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/convert/rgb2hex.js?");

/***/ }),

/***/ "../../node_modules/pure-color/parse/extractComponents.js":
/*!***************************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/parse/extractComponents.js ***!
  \***************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports) {

eval("var component = /-?\\d+(\\.\\d+)?%?/g;\nfunction extractComponents(color) {\n  return color.match(component);\n}\n\nmodule.exports = extractComponents;\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/parse/extractComponents.js?");

/***/ }),

/***/ "../../node_modules/pure-color/parse/hex.js":
/*!*************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/parse/hex.js ***!
  \*************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports) {

eval("function expand(hex) {\n  var result = \"#\";\n\n  for (var i = 1; i < hex.length; i++) {\n    var val = hex.charAt(i);\n    result += val + val;\n  }\n\n  return result;\n}\n\nfunction hex(hex) {\n  // #RGB or #RGBA\n  if(hex.length === 4 || hex.length === 5) {\n    hex = expand(hex);\n  }\n\n  var rgb = [\n    parseInt(hex.substring(1,3), 16),\n    parseInt(hex.substring(3,5), 16),\n    parseInt(hex.substring(5,7), 16)\n  ];\n\n  // #RRGGBBAA\n  if (hex.length === 9) {\n    var alpha = parseFloat((parseInt(hex.substring(7,9), 16) / 255).toFixed(2));\n    rgb.push(alpha);\n  }\n\n  return rgb;\n}\n\nmodule.exports = hex;\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/parse/hex.js?");

/***/ }),

/***/ "../../node_modules/pure-color/parse/hsl.js":
/*!*************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/parse/hsl.js ***!
  \*************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("var extractComponents = __webpack_require__(/*! ./extractComponents */ \"../../node_modules/pure-color/parse/extractComponents.js\");\nvar clamp = __webpack_require__(/*! ../util/clamp */ \"../../node_modules/pure-color/util/clamp.js\");\n\nfunction parseHslComponent(component, i) {\n  component = parseFloat(component);\n\n  switch(i) {\n    case 0:\n      return clamp(component, 0, 360);\n    case 1:\n    case 2:\n      return clamp(component, 0, 100);\n    case 3:\n      return clamp(component, 0, 1);\n  }\n}\n\nfunction hsl(color) {\n  return extractComponents(color).map(parseHslComponent);\n}\n\nmodule.exports = hsl;\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/parse/hsl.js?");

/***/ }),

/***/ "../../node_modules/pure-color/parse/index.js":
/*!***************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/parse/index.js ***!
  \***************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("var hsl = __webpack_require__(/*! ./hsl */ \"../../node_modules/pure-color/parse/hsl.js\");\nvar hex = __webpack_require__(/*! ./hex */ \"../../node_modules/pure-color/parse/hex.js\");\nvar rgb = __webpack_require__(/*! ./rgb */ \"../../node_modules/pure-color/parse/rgb.js\");\nvar hsl2rgb = __webpack_require__(/*! ../convert/hsl2rgb */ \"../../node_modules/pure-color/convert/hsl2rgb.js\");\n\nfunction hsl2rgbParse(color) {\n  var h = hsl(color);\n  var r = hsl2rgb(h);\n\n  // handle alpha since hsl2rgb doesn't know (or care!) about it\n  if(h.length === 4) {\n    r.push(h[3]);\n  }\n\n  return r;\n}\n\nvar space2parser = {\n  \"#\" : hex,\n  \"hsl\" : hsl2rgbParse,\n  \"rgb\" : rgb\n};\n\nfunction parse(color) {\n  for(var scheme in space2parser) {\n    if(color.indexOf(scheme) === 0) {\n      return space2parser[scheme](color);\n    }\n  }\n}\n\nparse.rgb = rgb;\nparse.hsl = hsl;\nparse.hex = hex;\n\nmodule.exports = parse;\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/parse/index.js?");

/***/ }),

/***/ "../../node_modules/pure-color/parse/rgb.js":
/*!*************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/parse/rgb.js ***!
  \*************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("var extractComponents = __webpack_require__(/*! ./extractComponents */ \"../../node_modules/pure-color/parse/extractComponents.js\");\nvar clamp = __webpack_require__(/*! ../util/clamp */ \"../../node_modules/pure-color/util/clamp.js\");\n\nfunction parseRgbComponent(component, i) {\n  if (i < 3) {\n    if (component.indexOf('%') != -1) {\n      return Math.round(255 * clamp(parseInt(component, 10), 0, 100)/100);\n    } else {\n      return clamp(parseInt(component, 10), 0, 255);\n    }\n  } else {\n    return clamp(parseFloat(component), 0, 1);\n  } \n}\n\nfunction rgb(color) {\n  return extractComponents(color).map(parseRgbComponent);\n}\n\nmodule.exports = rgb;\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/parse/rgb.js?");

/***/ }),

/***/ "../../node_modules/pure-color/util/clamp.js":
/*!**************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/util/clamp.js ***!
  \**************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports) {

eval("function clamp(val, min, max) {\n  return Math.min(Math.max(val, min), max);\n}\n\nmodule.exports = clamp;\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/pure-color/util/clamp.js?");

/***/ }),

/***/ "../../node_modules/react-is/cjs/react-is.development.js":
/*!**************************************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/react-is/cjs/react-is.development.js ***!
  \**************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("/** @license React v16.13.1\n * react-is.development.js\n *\n * Copyright (c) Facebook, Inc. and its affiliates.\n *\n * This source code is licensed under the MIT license found in the\n * LICENSE file in the root directory of this source tree.\n */\n\n\n\n\n\nif (true) {\n  (function() {\n'use strict';\n\n// The Symbol used to tag the ReactElement-like types. If there is no native Symbol\n// nor polyfill, then a plain number is used for performance.\nvar hasSymbol = typeof Symbol === 'function' && Symbol.for;\nvar REACT_ELEMENT_TYPE = hasSymbol ? Symbol.for('react.element') : 0xeac7;\nvar REACT_PORTAL_TYPE = hasSymbol ? Symbol.for('react.portal') : 0xeaca;\nvar REACT_FRAGMENT_TYPE = hasSymbol ? Symbol.for('react.fragment') : 0xeacb;\nvar REACT_STRICT_MODE_TYPE = hasSymbol ? Symbol.for('react.strict_mode') : 0xeacc;\nvar REACT_PROFILER_TYPE = hasSymbol ? Symbol.for('react.profiler') : 0xead2;\nvar REACT_PROVIDER_TYPE = hasSymbol ? Symbol.for('react.provider') : 0xeacd;\nvar REACT_CONTEXT_TYPE = hasSymbol ? Symbol.for('react.context') : 0xeace; // TODO: We don't use AsyncMode or ConcurrentMode anymore. They were temporary\n// (unstable) APIs that have been removed. Can we remove the symbols?\n\nvar REACT_ASYNC_MODE_TYPE = hasSymbol ? Symbol.for('react.async_mode') : 0xeacf;\nvar REACT_CONCURRENT_MODE_TYPE = hasSymbol ? Symbol.for('react.concurrent_mode') : 0xeacf;\nvar REACT_FORWARD_REF_TYPE = hasSymbol ? Symbol.for('react.forward_ref') : 0xead0;\nvar REACT_SUSPENSE_TYPE = hasSymbol ? Symbol.for('react.suspense') : 0xead1;\nvar REACT_SUSPENSE_LIST_TYPE = hasSymbol ? Symbol.for('react.suspense_list') : 0xead8;\nvar REACT_MEMO_TYPE = hasSymbol ? Symbol.for('react.memo') : 0xead3;\nvar REACT_LAZY_TYPE = hasSymbol ? Symbol.for('react.lazy') : 0xead4;\nvar REACT_BLOCK_TYPE = hasSymbol ? Symbol.for('react.block') : 0xead9;\nvar REACT_FUNDAMENTAL_TYPE = hasSymbol ? Symbol.for('react.fundamental') : 0xead5;\nvar REACT_RESPONDER_TYPE = hasSymbol ? Symbol.for('react.responder') : 0xead6;\nvar REACT_SCOPE_TYPE = hasSymbol ? Symbol.for('react.scope') : 0xead7;\n\nfunction isValidElementType(type) {\n  return typeof type === 'string' || typeof type === 'function' || // Note: its typeof might be other than 'symbol' or 'number' if it's a polyfill.\n  type === REACT_FRAGMENT_TYPE || type === REACT_CONCURRENT_MODE_TYPE || type === REACT_PROFILER_TYPE || type === REACT_STRICT_MODE_TYPE || type === REACT_SUSPENSE_TYPE || type === REACT_SUSPENSE_LIST_TYPE || typeof type === 'object' && type !== null && (type.$$typeof === REACT_LAZY_TYPE || type.$$typeof === REACT_MEMO_TYPE || type.$$typeof === REACT_PROVIDER_TYPE || type.$$typeof === REACT_CONTEXT_TYPE || type.$$typeof === REACT_FORWARD_REF_TYPE || type.$$typeof === REACT_FUNDAMENTAL_TYPE || type.$$typeof === REACT_RESPONDER_TYPE || type.$$typeof === REACT_SCOPE_TYPE || type.$$typeof === REACT_BLOCK_TYPE);\n}\n\nfunction typeOf(object) {\n  if (typeof object === 'object' && object !== null) {\n    var $$typeof = object.$$typeof;\n\n    switch ($$typeof) {\n      case REACT_ELEMENT_TYPE:\n        var type = object.type;\n\n        switch (type) {\n          case REACT_ASYNC_MODE_TYPE:\n          case REACT_CONCURRENT_MODE_TYPE:\n          case REACT_FRAGMENT_TYPE:\n          case REACT_PROFILER_TYPE:\n          case REACT_STRICT_MODE_TYPE:\n          case REACT_SUSPENSE_TYPE:\n            return type;\n\n          default:\n            var $$typeofType = type && type.$$typeof;\n\n            switch ($$typeofType) {\n              case REACT_CONTEXT_TYPE:\n              case REACT_FORWARD_REF_TYPE:\n              case REACT_LAZY_TYPE:\n              case REACT_MEMO_TYPE:\n              case REACT_PROVIDER_TYPE:\n                return $$typeofType;\n\n              default:\n                return $$typeof;\n            }\n\n        }\n\n      case REACT_PORTAL_TYPE:\n        return $$typeof;\n    }\n  }\n\n  return undefined;\n} // AsyncMode is deprecated along with isAsyncMode\n\nvar AsyncMode = REACT_ASYNC_MODE_TYPE;\nvar ConcurrentMode = REACT_CONCURRENT_MODE_TYPE;\nvar ContextConsumer = REACT_CONTEXT_TYPE;\nvar ContextProvider = REACT_PROVIDER_TYPE;\nvar Element = REACT_ELEMENT_TYPE;\nvar ForwardRef = REACT_FORWARD_REF_TYPE;\nvar Fragment = REACT_FRAGMENT_TYPE;\nvar Lazy = REACT_LAZY_TYPE;\nvar Memo = REACT_MEMO_TYPE;\nvar Portal = REACT_PORTAL_TYPE;\nvar Profiler = REACT_PROFILER_TYPE;\nvar StrictMode = REACT_STRICT_MODE_TYPE;\nvar Suspense = REACT_SUSPENSE_TYPE;\nvar hasWarnedAboutDeprecatedIsAsyncMode = false; // AsyncMode should be deprecated\n\nfunction isAsyncMode(object) {\n  {\n    if (!hasWarnedAboutDeprecatedIsAsyncMode) {\n      hasWarnedAboutDeprecatedIsAsyncMode = true; // Using console['warn'] to evade Babel and ESLint\n\n      console['warn']('The ReactIs.isAsyncMode() alias has been deprecated, ' + 'and will be removed in React 17+. Update your code to use ' + 'ReactIs.isConcurrentMode() instead. It has the exact same API.');\n    }\n  }\n\n  return isConcurrentMode(object) || typeOf(object) === REACT_ASYNC_MODE_TYPE;\n}\nfunction isConcurrentMode(object) {\n  return typeOf(object) === REACT_CONCURRENT_MODE_TYPE;\n}\nfunction isContextConsumer(object) {\n  return typeOf(object) === REACT_CONTEXT_TYPE;\n}\nfunction isContextProvider(object) {\n  return typeOf(object) === REACT_PROVIDER_TYPE;\n}\nfunction isElement(object) {\n  return typeof object === 'object' && object !== null && object.$$typeof === REACT_ELEMENT_TYPE;\n}\nfunction isForwardRef(object) {\n  return typeOf(object) === REACT_FORWARD_REF_TYPE;\n}\nfunction isFragment(object) {\n  return typeOf(object) === REACT_FRAGMENT_TYPE;\n}\nfunction isLazy(object) {\n  return typeOf(object) === REACT_LAZY_TYPE;\n}\nfunction isMemo(object) {\n  return typeOf(object) === REACT_MEMO_TYPE;\n}\nfunction isPortal(object) {\n  return typeOf(object) === REACT_PORTAL_TYPE;\n}\nfunction isProfiler(object) {\n  return typeOf(object) === REACT_PROFILER_TYPE;\n}\nfunction isStrictMode(object) {\n  return typeOf(object) === REACT_STRICT_MODE_TYPE;\n}\nfunction isSuspense(object) {\n  return typeOf(object) === REACT_SUSPENSE_TYPE;\n}\n\nexports.AsyncMode = AsyncMode;\nexports.ConcurrentMode = ConcurrentMode;\nexports.ContextConsumer = ContextConsumer;\nexports.ContextProvider = ContextProvider;\nexports.Element = Element;\nexports.ForwardRef = ForwardRef;\nexports.Fragment = Fragment;\nexports.Lazy = Lazy;\nexports.Memo = Memo;\nexports.Portal = Portal;\nexports.Profiler = Profiler;\nexports.StrictMode = StrictMode;\nexports.Suspense = Suspense;\nexports.isAsyncMode = isAsyncMode;\nexports.isConcurrentMode = isConcurrentMode;\nexports.isContextConsumer = isContextConsumer;\nexports.isContextProvider = isContextProvider;\nexports.isElement = isElement;\nexports.isForwardRef = isForwardRef;\nexports.isFragment = isFragment;\nexports.isLazy = isLazy;\nexports.isMemo = isMemo;\nexports.isPortal = isPortal;\nexports.isProfiler = isProfiler;\nexports.isStrictMode = isStrictMode;\nexports.isSuspense = isSuspense;\nexports.isValidElementType = isValidElementType;\nexports.typeOf = typeOf;\n  })();\n}\n\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/react-is/cjs/react-is.development.js?");

/***/ }),

/***/ "../../node_modules/react-is/index.js":
/*!*******************************************************************************!*\
  !*** C:/Users/Nathan/Documents/redux-devtools/node_modules/react-is/index.js ***!
  \*******************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nif (false) {} else {\n  module.exports = __webpack_require__(/*! ./cjs/react-is.development.js */ \"../../node_modules/react-is/cjs/react-is.development.js\");\n}\n\n\n//# sourceURL=webpack://ReactJsonTree/C:/Users/Nathan/Documents/redux-devtools/node_modules/react-is/index.js?");

/***/ }),

/***/ "../../node_modules/webpack/buildin/global.js":
/*!***********************************!*\
  !*** (webpack)/buildin/global.js ***!
  \***********************************/
/*! no static exports found */
/***/ (function(module, exports) {

eval("var g;\n\n// This works in non-strict mode\ng = (function() {\n\treturn this;\n})();\n\ntry {\n\t// This works if eval is allowed (see CSP)\n\tg = g || new Function(\"return this\")();\n} catch (e) {\n\t// This works if the window reference is available\n\tif (typeof window === \"object\") g = window;\n}\n\n// g can still be undefined, but nothing to do about it...\n// We return undefined, instead of nothing here, so it's\n// easier to handle this case. if(!global) { ...}\n\nmodule.exports = g;\n\n\n//# sourceURL=webpack://ReactJsonTree/(webpack)/buildin/global.js?");

/***/ }),

/***/ "../react-base16-styling/lib/colorConverters.js":
/*!******************************************************!*\
  !*** ../react-base16-styling/lib/colorConverters.js ***!
  \******************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nObject.defineProperty(exports, \"__esModule\", {\n  value: true\n});\nexports.yuv2rgb = yuv2rgb;\nexports.rgb2yuv = rgb2yuv;\n\nfunction yuv2rgb(yuv) {\n  var y = yuv[0],\n      u = yuv[1],\n      v = yuv[2],\n      r,\n      g,\n      b;\n  r = y * 1 + u * 0 + v * 1.13983;\n  g = y * 1 + u * -0.39465 + v * -0.5806;\n  b = y * 1 + u * 2.02311 + v * 0;\n  r = Math.min(Math.max(0, r), 1);\n  g = Math.min(Math.max(0, g), 1);\n  b = Math.min(Math.max(0, b), 1);\n  return [r * 255, g * 255, b * 255];\n}\n\nfunction rgb2yuv(rgb) {\n  var r = rgb[0] / 255,\n      g = rgb[1] / 255,\n      b = rgb[2] / 255;\n  var y = r * 0.299 + g * 0.587 + b * 0.114;\n  var u = r * -0.14713 + g * -0.28886 + b * 0.436;\n  var v = r * 0.615 + g * -0.51499 + b * -0.10001;\n  return [y, u, v];\n}\n\n//# sourceURL=webpack://ReactJsonTree/../react-base16-styling/lib/colorConverters.js?");

/***/ }),

/***/ "../react-base16-styling/lib/index.js":
/*!********************************************!*\
  !*** ../react-base16-styling/lib/index.js ***!
  \********************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\n\nObject.defineProperty(exports, \"__esModule\", {\n  value: true\n});\nexports.invertTheme = exports.getBase16Theme = exports.createStyling = exports.invertBase16Theme = void 0;\n\nvar _lodash = _interopRequireDefault(__webpack_require__(/*! lodash.curry */ \"../../node_modules/lodash.curry/index.js\"));\n\nvar base16 = _interopRequireWildcard(__webpack_require__(/*! base16 */ \"../../node_modules/base16/lib/index.js\"));\n\nvar _rgb2hex = _interopRequireDefault(__webpack_require__(/*! pure-color/convert/rgb2hex */ \"../../node_modules/pure-color/convert/rgb2hex.js\"));\n\nvar _parse = _interopRequireDefault(__webpack_require__(/*! pure-color/parse */ \"../../node_modules/pure-color/parse/index.js\"));\n\nvar _lodash2 = _interopRequireDefault(__webpack_require__(/*! lodash.flow */ \"../../node_modules/lodash.flow/index.js\"));\n\nvar _colorConverters = __webpack_require__(/*! ./colorConverters */ \"../react-base16-styling/lib/colorConverters.js\");\n\nfunction _getRequireWildcardCache() {\n  if (typeof WeakMap !== \"function\") return null;\n  var cache = new WeakMap();\n\n  _getRequireWildcardCache = function _getRequireWildcardCache() {\n    return cache;\n  };\n\n  return cache;\n}\n\nfunction _interopRequireWildcard(obj) {\n  if (obj && obj.__esModule) {\n    return obj;\n  }\n\n  if (obj === null || _typeof(obj) !== \"object\" && typeof obj !== \"function\") {\n    return {\n      \"default\": obj\n    };\n  }\n\n  var cache = _getRequireWildcardCache();\n\n  if (cache && cache.has(obj)) {\n    return cache.get(obj);\n  }\n\n  var newObj = {};\n  var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;\n\n  for (var key in obj) {\n    if (Object.prototype.hasOwnProperty.call(obj, key)) {\n      var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;\n\n      if (desc && (desc.get || desc.set)) {\n        Object.defineProperty(newObj, key, desc);\n      } else {\n        newObj[key] = obj[key];\n      }\n    }\n  }\n\n  newObj[\"default\"] = obj;\n\n  if (cache) {\n    cache.set(obj, newObj);\n  }\n\n  return newObj;\n}\n\nfunction _interopRequireDefault(obj) {\n  return obj && obj.__esModule ? obj : {\n    \"default\": obj\n  };\n}\n\nfunction _typeof(obj) {\n  \"@babel/helpers - typeof\";\n\n  if (typeof Symbol === \"function\" && typeof Symbol.iterator === \"symbol\") {\n    _typeof = function _typeof(obj) {\n      return typeof obj;\n    };\n  } else {\n    _typeof = function _typeof(obj) {\n      return obj && typeof Symbol === \"function\" && obj.constructor === Symbol && obj !== Symbol.prototype ? \"symbol\" : typeof obj;\n    };\n  }\n\n  return _typeof(obj);\n}\n\nfunction ownKeys(object, enumerableOnly) {\n  var keys = Object.keys(object);\n\n  if (Object.getOwnPropertySymbols) {\n    var symbols = Object.getOwnPropertySymbols(object);\n    if (enumerableOnly) symbols = symbols.filter(function (sym) {\n      return Object.getOwnPropertyDescriptor(object, sym).enumerable;\n    });\n    keys.push.apply(keys, symbols);\n  }\n\n  return keys;\n}\n\nfunction _objectSpread(target) {\n  for (var i = 1; i < arguments.length; i++) {\n    var source = arguments[i] != null ? arguments[i] : {};\n\n    if (i % 2) {\n      ownKeys(Object(source), true).forEach(function (key) {\n        _defineProperty(target, key, source[key]);\n      });\n    } else if (Object.getOwnPropertyDescriptors) {\n      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));\n    } else {\n      ownKeys(Object(source)).forEach(function (key) {\n        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));\n      });\n    }\n  }\n\n  return target;\n}\n\nfunction _defineProperty(obj, key, value) {\n  if (key in obj) {\n    Object.defineProperty(obj, key, {\n      value: value,\n      enumerable: true,\n      configurable: true,\n      writable: true\n    });\n  } else {\n    obj[key] = value;\n  }\n\n  return obj;\n}\n\nfunction _slicedToArray(arr, i) {\n  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();\n}\n\nfunction _nonIterableRest() {\n  throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\");\n}\n\nfunction _unsupportedIterableToArray(o, minLen) {\n  if (!o) return;\n  if (typeof o === \"string\") return _arrayLikeToArray(o, minLen);\n  var n = Object.prototype.toString.call(o).slice(8, -1);\n  if (n === \"Object\" && o.constructor) n = o.constructor.name;\n  if (n === \"Map\" || n === \"Set\") return Array.from(o);\n  if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);\n}\n\nfunction _arrayLikeToArray(arr, len) {\n  if (len == null || len > arr.length) len = arr.length;\n\n  for (var i = 0, arr2 = new Array(len); i < len; i++) {\n    arr2[i] = arr[i];\n  }\n\n  return arr2;\n}\n\nfunction _iterableToArrayLimit(arr, i) {\n  if (typeof Symbol === \"undefined\" || !(Symbol.iterator in Object(arr))) return;\n  var _arr = [];\n  var _n = true;\n  var _d = false;\n  var _e = undefined;\n\n  try {\n    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {\n      _arr.push(_s.value);\n\n      if (i && _arr.length === i) break;\n    }\n  } catch (err) {\n    _d = true;\n    _e = err;\n  } finally {\n    try {\n      if (!_n && _i[\"return\"] != null) _i[\"return\"]();\n    } finally {\n      if (_d) throw _e;\n    }\n  }\n\n  return _arr;\n}\n\nfunction _arrayWithHoles(arr) {\n  if (Array.isArray(arr)) return arr;\n}\n\nvar DEFAULT_BASE16 = base16[\"default\"];\nvar BASE16_KEYS = Object.keys(DEFAULT_BASE16); // we need a correcting factor, so that a dark, but not black background color\n// converts to bright enough inversed color\n\nvar flip = function flip(x) {\n  return x < 0.25 ? 1 : x < 0.5 ? 0.9 - x : 1.1 - x;\n};\n\nvar invertColor = (0, _lodash2[\"default\"])(_parse[\"default\"], _colorConverters.rgb2yuv, function (_ref) {\n  var _ref2 = _slicedToArray(_ref, 3),\n      y = _ref2[0],\n      u = _ref2[1],\n      v = _ref2[2];\n\n  return [flip(y), u, v];\n}, _colorConverters.yuv2rgb, _rgb2hex[\"default\"]);\n\nvar merger = function merger(styling) {\n  return function (prevStyling) {\n    return {\n      className: [prevStyling.className, styling.className].filter(Boolean).join(' '),\n      style: _objectSpread(_objectSpread({}, prevStyling.style || {}), styling.style || {})\n    };\n  };\n};\n\nvar mergeStyling = function mergeStyling(customStyling, defaultStyling) {\n  if (customStyling === undefined) {\n    return defaultStyling;\n  }\n\n  if (defaultStyling === undefined) {\n    return customStyling;\n  }\n\n  var customType = _typeof(customStyling);\n\n  var defaultType = _typeof(defaultStyling);\n\n  switch (customType) {\n    case 'string':\n      switch (defaultType) {\n        case 'string':\n          return [defaultStyling, customStyling].filter(Boolean).join(' ');\n\n        case 'object':\n          return merger({\n            className: customStyling,\n            style: defaultStyling\n          });\n\n        case 'function':\n          return function (styling) {\n            for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {\n              args[_key - 1] = arguments[_key];\n            }\n\n            return merger({\n              className: customStyling\n            })(defaultStyling.apply(void 0, [styling].concat(args)));\n          };\n      }\n\n      break;\n\n    case 'object':\n      switch (defaultType) {\n        case 'string':\n          return merger({\n            className: defaultStyling,\n            style: customStyling\n          });\n\n        case 'object':\n          return _objectSpread(_objectSpread({}, defaultStyling), customStyling);\n\n        case 'function':\n          return function (styling) {\n            for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {\n              args[_key2 - 1] = arguments[_key2];\n            }\n\n            return merger({\n              style: customStyling\n            })(defaultStyling.apply(void 0, [styling].concat(args)));\n          };\n      }\n\n      break;\n\n    case 'function':\n      switch (defaultType) {\n        case 'string':\n          return function (styling) {\n            for (var _len3 = arguments.length, args = new Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {\n              args[_key3 - 1] = arguments[_key3];\n            }\n\n            return customStyling.apply(void 0, [merger(styling)({\n              className: defaultStyling\n            })].concat(args));\n          };\n\n        case 'object':\n          return function (styling) {\n            for (var _len4 = arguments.length, args = new Array(_len4 > 1 ? _len4 - 1 : 0), _key4 = 1; _key4 < _len4; _key4++) {\n              args[_key4 - 1] = arguments[_key4];\n            }\n\n            return customStyling.apply(void 0, [merger(styling)({\n              style: defaultStyling\n            })].concat(args));\n          };\n\n        case 'function':\n          return function (styling) {\n            for (var _len5 = arguments.length, args = new Array(_len5 > 1 ? _len5 - 1 : 0), _key5 = 1; _key5 < _len5; _key5++) {\n              args[_key5 - 1] = arguments[_key5];\n            }\n\n            return customStyling.apply(void 0, [defaultStyling.apply(void 0, [styling].concat(args))].concat(args));\n          };\n      }\n\n  }\n};\n\nvar mergeStylings = function mergeStylings(customStylings, defaultStylings) {\n  var keys = Object.keys(defaultStylings);\n\n  for (var key in customStylings) {\n    if (keys.indexOf(key) === -1) keys.push(key);\n  }\n\n  return keys.reduce(function (mergedStyling, key) {\n    return mergedStyling[key] = mergeStyling(customStylings[key], defaultStylings[key]), mergedStyling;\n  }, {});\n};\n\nvar getStylingByKeys = function getStylingByKeys(mergedStyling, keys) {\n  for (var _len6 = arguments.length, args = new Array(_len6 > 2 ? _len6 - 2 : 0), _key6 = 2; _key6 < _len6; _key6++) {\n    args[_key6 - 2] = arguments[_key6];\n  }\n\n  if (keys === null) {\n    return mergedStyling;\n  }\n\n  if (!Array.isArray(keys)) {\n    keys = [keys];\n  }\n\n  var styles = keys.map(function (key) {\n    return mergedStyling[key];\n  }).filter(Boolean);\n  var props = styles.reduce(function (obj, s) {\n    if (typeof s === 'string') {\n      obj.className = [obj.className, s].filter(Boolean).join(' ');\n    } else if (_typeof(s) === 'object') {\n      obj.style = _objectSpread(_objectSpread({}, obj.style), s);\n    } else if (typeof s === 'function') {\n      obj = _objectSpread(_objectSpread({}, obj), s.apply(void 0, [obj].concat(args)));\n    }\n\n    return obj;\n  }, {\n    className: '',\n    style: {}\n  });\n\n  if (!props.className) {\n    delete props.className;\n  }\n\n  if (Object.keys(props.style).length === 0) {\n    delete props.style;\n  }\n\n  return props;\n};\n\nvar invertBase16Theme = function invertBase16Theme(base16Theme) {\n  return Object.keys(base16Theme).reduce(function (t, key) {\n    return t[key] = /^base/.test(key) ? invertColor(base16Theme[key]) : key === 'scheme' ? base16Theme[key] + ':inverted' : base16Theme[key], t;\n  }, {});\n};\n\nexports.invertBase16Theme = invertBase16Theme;\nvar createStyling = (0, _lodash[\"default\"])(function (getStylingFromBase16) {\n  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};\n  var themeOrStyling = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};\n  var _options$defaultBase = options.defaultBase16,\n      defaultBase16 = _options$defaultBase === void 0 ? DEFAULT_BASE16 : _options$defaultBase,\n      _options$base16Themes = options.base16Themes,\n      base16Themes = _options$base16Themes === void 0 ? null : _options$base16Themes;\n  var base16Theme = getBase16Theme(themeOrStyling, base16Themes);\n\n  if (base16Theme) {\n    themeOrStyling = _objectSpread(_objectSpread({}, base16Theme), themeOrStyling);\n  }\n\n  var theme = BASE16_KEYS.reduce(function (t, key) {\n    return t[key] = themeOrStyling[key] || defaultBase16[key], t;\n  }, {});\n  var customStyling = Object.keys(themeOrStyling).reduce(function (s, key) {\n    return BASE16_KEYS.indexOf(key) === -1 ? (s[key] = themeOrStyling[key], s) : s;\n  }, {});\n  var defaultStyling = getStylingFromBase16(theme);\n  var mergedStyling = mergeStylings(customStyling, defaultStyling);\n\n  for (var _len7 = arguments.length, args = new Array(_len7 > 3 ? _len7 - 3 : 0), _key7 = 3; _key7 < _len7; _key7++) {\n    args[_key7 - 3] = arguments[_key7];\n  }\n\n  return (0, _lodash[\"default\"])(getStylingByKeys, 2).apply(void 0, [mergedStyling].concat(args));\n}, 3);\nexports.createStyling = createStyling;\n\nvar getBase16Theme = function getBase16Theme(theme, base16Themes) {\n  if (theme && theme.extend) {\n    theme = theme.extend;\n  }\n\n  if (typeof theme === 'string') {\n    var _theme$split = theme.split(':'),\n        _theme$split2 = _slicedToArray(_theme$split, 2),\n        themeName = _theme$split2[0],\n        modifier = _theme$split2[1];\n\n    theme = (base16Themes || {})[themeName] || base16[themeName];\n\n    if (modifier === 'inverted') {\n      theme = invertBase16Theme(theme);\n    }\n  }\n\n  return theme && Object.prototype.hasOwnProperty.call(theme, 'base00') ? theme : undefined;\n};\n\nexports.getBase16Theme = getBase16Theme;\n\nvar invertTheme = function invertTheme(theme) {\n  if (typeof theme === 'string') {\n    return \"\".concat(theme, \":inverted\");\n  }\n\n  if (theme && theme.extend) {\n    if (typeof theme.extend === 'string') {\n      return _objectSpread(_objectSpread({}, theme), {}, {\n        extend: \"\".concat(theme.extend, \":inverted\")\n      });\n    }\n\n    return _objectSpread(_objectSpread({}, theme), {}, {\n      extend: invertBase16Theme(theme.extend)\n    });\n  }\n\n  if (theme) {\n    return invertBase16Theme(theme);\n  }\n};\n\nexports.invertTheme = invertTheme;\n\n//# sourceURL=webpack://ReactJsonTree/../react-base16-styling/lib/index.js?");

/***/ }),

/***/ "./src/ItemRange.js":
/*!**************************!*\
  !*** ./src/ItemRange.js ***!
  \**************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"default\", function() { return ItemRange; });\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ \"react\");\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ \"../../node_modules/prop-types/index.js\");\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var _JSONArrow__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./JSONArrow */ \"./src/JSONArrow.js\");\nfunction _typeof(obj) { \"@babel/helpers - typeof\"; if (typeof Symbol === \"function\" && typeof Symbol.iterator === \"symbol\") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === \"function\" && obj.constructor === Symbol && obj !== Symbol.prototype ? \"symbol\" : typeof obj; }; } return _typeof(obj); }\n\nfunction _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function\"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }\n\nfunction _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }\n\nfunction _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }\n\nfunction _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === \"object\" || typeof call === \"function\")) { return call; } return _assertThisInitialized(self); }\n\nfunction _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return self; }\n\nfunction _isNativeReflectConstruct() { if (typeof Reflect === \"undefined\" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === \"function\") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\nfunction _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }\n\n\n\n\n\nvar ItemRange = /*#__PURE__*/function (_React$Component) {\n  _inherits(ItemRange, _React$Component);\n\n  var _super = _createSuper(ItemRange);\n\n  function ItemRange(props) {\n    var _this;\n\n    _classCallCheck(this, ItemRange);\n\n    _this = _super.call(this, props);\n    _this.state = {\n      expanded: false\n    };\n    _this.handleClick = _this.handleClick.bind(_assertThisInitialized(_this));\n    return _this;\n  }\n\n  _createClass(ItemRange, [{\n    key: \"render\",\n    value: function render() {\n      var _this$props = this.props,\n          styling = _this$props.styling,\n          from = _this$props.from,\n          to = _this$props.to,\n          renderChildNodes = _this$props.renderChildNodes,\n          nodeType = _this$props.nodeType;\n      return this.state.expanded ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"div\", styling('itemRange', this.state.expanded), renderChildNodes(this.props, from, to)) : /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"div\", _extends({}, styling('itemRange', this.state.expanded), {\n        onClick: this.handleClick\n      }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONArrow__WEBPACK_IMPORTED_MODULE_2__[\"default\"], {\n        nodeType: nodeType,\n        styling: styling,\n        expanded: false,\n        onClick: this.handleClick,\n        arrowStyle: \"double\"\n      }), \"\".concat(from, \" ... \").concat(to));\n    }\n  }, {\n    key: \"handleClick\",\n    value: function handleClick() {\n      this.setState({\n        expanded: !this.state.expanded\n      });\n    }\n  }]);\n\n  return ItemRange;\n}(react__WEBPACK_IMPORTED_MODULE_0___default.a.Component);\n\n_defineProperty(ItemRange, \"propTypes\", {\n  styling: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  from: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number.isRequired,\n  to: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number.isRequired,\n  renderChildNodes: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  nodeType: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string.isRequired\n});\n\n\n\n//# sourceURL=webpack://ReactJsonTree/./src/ItemRange.js?");

/***/ }),

/***/ "./src/JSONArrayNode.js":
/*!******************************!*\
  !*** ./src/JSONArrayNode.js ***!
  \******************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ \"react\");\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ \"../../node_modules/prop-types/index.js\");\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var _JSONNestedNode__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./JSONNestedNode */ \"./src/JSONNestedNode.js\");\nfunction _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }\n\nfunction _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }\n\nfunction _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }\n\n\n\n // Returns the \"n Items\" string for this node,\n// generating and caching it if it hasn't been created yet.\n\nfunction createItemString(data) {\n  return \"\".concat(data.length, \" \").concat(data.length !== 1 ? 'items' : 'item');\n} // Configures <JSONNestedNode> to render an Array\n\n\nvar JSONArrayNode = function JSONArrayNode(_ref) {\n  var data = _ref.data,\n      props = _objectWithoutProperties(_ref, [\"data\"]);\n\n  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONNestedNode__WEBPACK_IMPORTED_MODULE_2__[\"default\"], _extends({}, props, {\n    data: data,\n    nodeType: \"Array\",\n    nodeTypeIndicator: \"[]\",\n    createItemString: createItemString,\n    expandable: data.length > 0\n  }));\n};\n\nJSONArrayNode.propTypes = {\n  data: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.array\n};\n/* harmony default export */ __webpack_exports__[\"default\"] = (JSONArrayNode);\n\n//# sourceURL=webpack://ReactJsonTree/./src/JSONArrayNode.js?");

/***/ }),

/***/ "./src/JSONArrow.js":
/*!**************************!*\
  !*** ./src/JSONArrow.js ***!
  \**************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ \"react\");\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ \"../../node_modules/prop-types/index.js\");\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);\nfunction _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }\n\n\n\n\nvar JSONArrow = function JSONArrow(_ref) {\n  var styling = _ref.styling,\n      arrowStyle = _ref.arrowStyle,\n      expanded = _ref.expanded,\n      nodeType = _ref.nodeType,\n      onClick = _ref.onClick;\n  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"div\", _extends({}, styling('arrowContainer', arrowStyle), {\n    onClick: onClick\n  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"div\", styling(['arrow', 'arrowSign'], nodeType, expanded, arrowStyle), \"\\u25B6\", arrowStyle === 'double' && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"div\", styling(['arrowSign', 'arrowSignInner']), \"\\u25B6\")));\n};\n\nJSONArrow.propTypes = {\n  styling: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  arrowStyle: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(['single', 'double']),\n  expanded: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool.isRequired,\n  nodeType: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string.isRequired,\n  onClick: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired\n};\nJSONArrow.defaultProps = {\n  arrowStyle: 'single'\n};\n/* harmony default export */ __webpack_exports__[\"default\"] = (JSONArrow);\n\n//# sourceURL=webpack://ReactJsonTree/./src/JSONArrow.js?");

/***/ }),

/***/ "./src/JSONIterableNode.js":
/*!*********************************!*\
  !*** ./src/JSONIterableNode.js ***!
  \*********************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"default\", function() { return JSONIterableNode; });\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ \"react\");\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var _JSONNestedNode__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./JSONNestedNode */ \"./src/JSONNestedNode.js\");\nfunction _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }\n\nfunction _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === \"undefined\" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === \"number\") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError(\"Invalid attempt to iterate non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it[\"return\"] != null) it[\"return\"](); } finally { if (didErr) throw err; } } }; }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }\n\n\n // Returns the \"n Items\" string for this node,\n// generating and caching it if it hasn't been created yet.\n\nfunction createItemString(data, limit) {\n  var count = 0;\n  var hasMore = false;\n\n  if (Number.isSafeInteger(data.size)) {\n    count = data.size;\n  } else {\n    // eslint-disable-next-line no-unused-vars\n    var _iterator = _createForOfIteratorHelper(data),\n        _step;\n\n    try {\n      for (_iterator.s(); !(_step = _iterator.n()).done;) {\n        var entry = _step.value;\n\n        if (limit && count + 1 > limit) {\n          hasMore = true;\n          break;\n        }\n\n        count += 1;\n      }\n    } catch (err) {\n      _iterator.e(err);\n    } finally {\n      _iterator.f();\n    }\n  }\n\n  return \"\".concat(hasMore ? '>' : '').concat(count, \" \").concat(count !== 1 ? 'entries' : 'entry');\n} // Configures <JSONNestedNode> to render an iterable\n\n\nfunction JSONIterableNode(_ref) {\n  var props = _extends({}, _ref);\n\n  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONNestedNode__WEBPACK_IMPORTED_MODULE_1__[\"default\"], _extends({}, props, {\n    nodeType: \"Iterable\",\n    nodeTypeIndicator: \"()\",\n    createItemString: createItemString\n  }));\n}\n\n//# sourceURL=webpack://ReactJsonTree/./src/JSONIterableNode.js?");

/***/ }),

/***/ "./src/JSONNestedNode.js":
/*!*******************************!*\
  !*** ./src/JSONNestedNode.js ***!
  \*******************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"default\", function() { return JSONNestedNode; });\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ \"react\");\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ \"../../node_modules/prop-types/index.js\");\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var _JSONArrow__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./JSONArrow */ \"./src/JSONArrow.js\");\n/* harmony import */ var _getCollectionEntries__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./getCollectionEntries */ \"./src/getCollectionEntries.js\");\n/* harmony import */ var _JSONNode__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./JSONNode */ \"./src/JSONNode.js\");\n/* harmony import */ var _ItemRange__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./ItemRange */ \"./src/ItemRange.js\");\nfunction _typeof(obj) { \"@babel/helpers - typeof\"; if (typeof Symbol === \"function\" && typeof Symbol.iterator === \"symbol\") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === \"function\" && obj.constructor === Symbol && obj !== Symbol.prototype ? \"symbol\" : typeof obj; }; } return _typeof(obj); }\n\nfunction ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }\n\nfunction _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function\"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }\n\nfunction _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }\n\nfunction _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }\n\nfunction _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === \"object\" || typeof call === \"function\")) { return call; } return _assertThisInitialized(self); }\n\nfunction _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return self; }\n\nfunction _isNativeReflectConstruct() { if (typeof Reflect === \"undefined\" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === \"function\") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\nfunction _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }\n\nfunction _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }\n\nfunction _nonIterableSpread() { throw new TypeError(\"Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }\n\nfunction _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }\n\n\n\n\n\n\n\n/**\n * Renders nested values (eg. objects, arrays, lists, etc.)\n */\n\nfunction renderChildNodes(props, from, to) {\n  var nodeType = props.nodeType,\n      data = props.data,\n      collectionLimit = props.collectionLimit,\n      circularCache = props.circularCache,\n      keyPath = props.keyPath,\n      postprocessValue = props.postprocessValue,\n      sortObjectKeys = props.sortObjectKeys;\n  var childNodes = [];\n  Object(_getCollectionEntries__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(nodeType, data, sortObjectKeys, collectionLimit, from, to).forEach(function (entry) {\n    if (entry.to) {\n      childNodes.push( /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_ItemRange__WEBPACK_IMPORTED_MODULE_5__[\"default\"], _extends({}, props, {\n        key: \"ItemRange--\".concat(entry.from, \"-\").concat(entry.to),\n        from: entry.from,\n        to: entry.to,\n        renderChildNodes: renderChildNodes\n      })));\n    } else {\n      var key = entry.key,\n          value = entry.value;\n      var isCircular = circularCache.indexOf(value) !== -1;\n      var node = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONNode__WEBPACK_IMPORTED_MODULE_4__[\"default\"], _extends({}, props, {\n        postprocessValue: postprocessValue,\n        collectionLimit: collectionLimit\n      }, {\n        key: \"Node--\".concat(key),\n        keyPath: [key].concat(_toConsumableArray(keyPath)),\n        value: postprocessValue(value),\n        circularCache: [].concat(_toConsumableArray(circularCache), [value]),\n        isCircular: isCircular,\n        hideRoot: false\n      }));\n\n      if (node !== false) {\n        childNodes.push(node);\n      }\n    }\n  });\n  return childNodes;\n}\n\nfunction getStateFromProps(props) {\n  // calculate individual node expansion if necessary\n  var expanded = props.shouldExpandNode && !props.isCircular ? props.shouldExpandNode(props.keyPath, props.data, props.level) : false;\n  return {\n    expanded: expanded\n  };\n}\n\nvar JSONNestedNode = /*#__PURE__*/function (_React$Component) {\n  _inherits(JSONNestedNode, _React$Component);\n\n  var _super = _createSuper(JSONNestedNode);\n\n  function JSONNestedNode(props) {\n    var _this;\n\n    _classCallCheck(this, JSONNestedNode);\n\n    _this = _super.call(this, props);\n\n    _defineProperty(_assertThisInitialized(_this), \"handleClick\", function () {\n      if (_this.props.expandable) {\n        _this.setState({\n          expanded: !_this.state.expanded\n        });\n      }\n    });\n\n    _this.state = getStateFromProps(props);\n    return _this;\n  }\n\n  _createClass(JSONNestedNode, [{\n    key: \"UNSAFE_componentWillReceiveProps\",\n    value: function UNSAFE_componentWillReceiveProps(nextProps) {\n      var nextState = getStateFromProps(nextProps);\n\n      if (getStateFromProps(this.props).expanded !== nextState.expanded) {\n        this.setState(nextState);\n      }\n    }\n  }, {\n    key: \"shouldComponentUpdate\",\n    value: function shouldComponentUpdate(nextProps, nextState) {\n      var _this2 = this;\n\n      return !!Object.keys(nextProps).find(function (key) {\n        return key !== 'circularCache' && (key === 'keyPath' ? nextProps[key].join('/') !== _this2.props[key].join('/') : nextProps[key] !== _this2.props[key]);\n      }) || nextState.expanded !== this.state.expanded;\n    }\n  }, {\n    key: \"render\",\n    value: function render() {\n      var _this$props = this.props,\n          getItemString = _this$props.getItemString,\n          nodeTypeIndicator = _this$props.nodeTypeIndicator,\n          nodeType = _this$props.nodeType,\n          data = _this$props.data,\n          hideRoot = _this$props.hideRoot,\n          createItemString = _this$props.createItemString,\n          styling = _this$props.styling,\n          collectionLimit = _this$props.collectionLimit,\n          keyPath = _this$props.keyPath,\n          labelRenderer = _this$props.labelRenderer,\n          expandable = _this$props.expandable;\n      var expanded = this.state.expanded;\n      var renderedChildren = expanded || hideRoot && this.props.level === 0 ? renderChildNodes(_objectSpread(_objectSpread({}, this.props), {}, {\n        level: this.props.level + 1\n      })) : null;\n      var itemType = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"span\", styling('nestedNodeItemType', expanded), nodeTypeIndicator);\n      var renderedItemString = getItemString(nodeType, data, itemType, createItemString(data, collectionLimit));\n      var stylingArgs = [keyPath, nodeType, expanded, expandable];\n      return hideRoot ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"li\", styling.apply(void 0, ['rootNode'].concat(stylingArgs)), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"ul\", styling.apply(void 0, ['rootNodeChildren'].concat(stylingArgs)), renderedChildren)) : /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"li\", styling.apply(void 0, ['nestedNode'].concat(stylingArgs)), expandable && /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONArrow__WEBPACK_IMPORTED_MODULE_2__[\"default\"], {\n        styling: styling,\n        nodeType: nodeType,\n        expanded: expanded,\n        onClick: this.handleClick\n      }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"label\", _extends({}, styling.apply(void 0, [['label', 'nestedNodeLabel']].concat(stylingArgs)), {\n        onClick: this.handleClick\n      }), labelRenderer.apply(void 0, stylingArgs)), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"span\", _extends({}, styling.apply(void 0, ['nestedNodeItemString'].concat(stylingArgs)), {\n        onClick: this.handleClick\n      }), renderedItemString), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"ul\", styling.apply(void 0, ['nestedNodeChildren'].concat(stylingArgs)), renderedChildren));\n    }\n  }]);\n\n  return JSONNestedNode;\n}(react__WEBPACK_IMPORTED_MODULE_0___default.a.Component);\n\n_defineProperty(JSONNestedNode, \"propTypes\", {\n  getItemString: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  nodeTypeIndicator: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.any,\n  nodeType: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string.isRequired,\n  data: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.any,\n  hideRoot: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool.isRequired,\n  createItemString: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  styling: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  collectionLimit: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,\n  keyPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.arrayOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])).isRequired,\n  labelRenderer: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  shouldExpandNode: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func,\n  level: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number.isRequired,\n  sortObjectKeys: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool]),\n  isCircular: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,\n  expandable: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool\n});\n\n_defineProperty(JSONNestedNode, \"defaultProps\", {\n  data: [],\n  circularCache: [],\n  level: 0,\n  expandable: true\n});\n\n\n\n//# sourceURL=webpack://ReactJsonTree/./src/JSONNestedNode.js?");

/***/ }),

/***/ "./src/JSONNode.js":
/*!*************************!*\
  !*** ./src/JSONNode.js ***!
  \*************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ \"react\");\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ \"../../node_modules/prop-types/index.js\");\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var _objType__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./objType */ \"./src/objType.js\");\n/* harmony import */ var _JSONObjectNode__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./JSONObjectNode */ \"./src/JSONObjectNode.js\");\n/* harmony import */ var _JSONArrayNode__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./JSONArrayNode */ \"./src/JSONArrayNode.js\");\n/* harmony import */ var _JSONIterableNode__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./JSONIterableNode */ \"./src/JSONIterableNode.js\");\n/* harmony import */ var _JSONValueNode__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./JSONValueNode */ \"./src/JSONValueNode.js\");\nfunction _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }\n\nfunction ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }\n\nfunction _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }\n\nfunction _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }\n\nfunction _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }\n\nfunction _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }\n\n\n\n\n\n\n\n\n\nvar JSONNode = function JSONNode(_ref) {\n  var getItemString = _ref.getItemString,\n      keyPath = _ref.keyPath,\n      labelRenderer = _ref.labelRenderer,\n      styling = _ref.styling,\n      value = _ref.value,\n      valueRenderer = _ref.valueRenderer,\n      isCustomNode = _ref.isCustomNode,\n      rest = _objectWithoutProperties(_ref, [\"getItemString\", \"keyPath\", \"labelRenderer\", \"styling\", \"value\", \"valueRenderer\", \"isCustomNode\"]);\n\n  var nodeType = isCustomNode(value) ? 'Custom' : Object(_objType__WEBPACK_IMPORTED_MODULE_2__[\"default\"])(value);\n  var simpleNodeProps = {\n    getItemString: getItemString,\n    key: keyPath[0],\n    keyPath: keyPath,\n    labelRenderer: labelRenderer,\n    nodeType: nodeType,\n    styling: styling,\n    value: value,\n    valueRenderer: valueRenderer\n  };\n\n  var nestedNodeProps = _objectSpread(_objectSpread(_objectSpread({}, rest), simpleNodeProps), {}, {\n    data: value,\n    isCustomNode: isCustomNode\n  });\n\n  switch (nodeType) {\n    case 'Object':\n    case 'Error':\n    case 'WeakMap':\n    case 'WeakSet':\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONObjectNode__WEBPACK_IMPORTED_MODULE_3__[\"default\"], nestedNodeProps);\n\n    case 'Array':\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONArrayNode__WEBPACK_IMPORTED_MODULE_4__[\"default\"], nestedNodeProps);\n\n    case 'Iterable':\n    case 'Map':\n    case 'Set':\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONIterableNode__WEBPACK_IMPORTED_MODULE_5__[\"default\"], nestedNodeProps);\n\n    case 'String':\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONValueNode__WEBPACK_IMPORTED_MODULE_6__[\"default\"], _extends({}, simpleNodeProps, {\n        valueGetter: function valueGetter(raw) {\n          return \"\\\"\".concat(raw, \"\\\"\");\n        }\n      }));\n\n    case 'Number':\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONValueNode__WEBPACK_IMPORTED_MODULE_6__[\"default\"], simpleNodeProps);\n\n    case 'Boolean':\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONValueNode__WEBPACK_IMPORTED_MODULE_6__[\"default\"], _extends({}, simpleNodeProps, {\n        valueGetter: function valueGetter(raw) {\n          return raw ? 'true' : 'false';\n        }\n      }));\n\n    case 'Date':\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONValueNode__WEBPACK_IMPORTED_MODULE_6__[\"default\"], _extends({}, simpleNodeProps, {\n        valueGetter: function valueGetter(raw) {\n          return raw.toISOString();\n        }\n      }));\n\n    case 'Null':\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONValueNode__WEBPACK_IMPORTED_MODULE_6__[\"default\"], _extends({}, simpleNodeProps, {\n        valueGetter: function valueGetter() {\n          return 'null';\n        }\n      }));\n\n    case 'Undefined':\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONValueNode__WEBPACK_IMPORTED_MODULE_6__[\"default\"], _extends({}, simpleNodeProps, {\n        valueGetter: function valueGetter() {\n          return 'undefined';\n        }\n      }));\n\n    case 'Function':\n    case 'Symbol':\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONValueNode__WEBPACK_IMPORTED_MODULE_6__[\"default\"], _extends({}, simpleNodeProps, {\n        valueGetter: function valueGetter(raw) {\n          return raw.toString();\n        }\n      }));\n\n    case 'Custom':\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONValueNode__WEBPACK_IMPORTED_MODULE_6__[\"default\"], simpleNodeProps);\n\n    default:\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONValueNode__WEBPACK_IMPORTED_MODULE_6__[\"default\"], _extends({}, simpleNodeProps, {\n        valueGetter: function valueGetter() {\n          return \"<\".concat(nodeType, \">\");\n        }\n      }));\n  }\n};\n\nJSONNode.propTypes = {\n  getItemString: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  keyPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.arrayOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])).isRequired,\n  labelRenderer: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  styling: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  value: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.any,\n  valueRenderer: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  isCustomNode: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired\n};\n/* harmony default export */ __webpack_exports__[\"default\"] = (JSONNode);\n\n//# sourceURL=webpack://ReactJsonTree/./src/JSONNode.js?");

/***/ }),

/***/ "./src/JSONObjectNode.js":
/*!*******************************!*\
  !*** ./src/JSONObjectNode.js ***!
  \*******************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ \"react\");\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ \"../../node_modules/prop-types/index.js\");\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var _JSONNestedNode__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./JSONNestedNode */ \"./src/JSONNestedNode.js\");\nfunction _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }\n\nfunction _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }\n\nfunction _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }\n\n\n\n // Returns the \"n Items\" string for this node,\n// generating and caching it if it hasn't been created yet.\n\nfunction createItemString(data) {\n  var len = Object.getOwnPropertyNames(data).length;\n  return \"\".concat(len, \" \").concat(len !== 1 ? 'keys' : 'key');\n} // Configures <JSONNestedNode> to render an Object\n\n\nvar JSONObjectNode = function JSONObjectNode(_ref) {\n  var data = _ref.data,\n      props = _objectWithoutProperties(_ref, [\"data\"]);\n\n  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONNestedNode__WEBPACK_IMPORTED_MODULE_2__[\"default\"], _extends({}, props, {\n    data: data,\n    nodeType: \"Object\",\n    nodeTypeIndicator: props.nodeType === 'Error' ? 'Error()' : '{}',\n    createItemString: createItemString,\n    expandable: Object.getOwnPropertyNames(data).length > 0\n  }));\n};\n\nJSONObjectNode.propTypes = {\n  data: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.object,\n  nodeType: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string\n};\n/* harmony default export */ __webpack_exports__[\"default\"] = (JSONObjectNode);\n\n//# sourceURL=webpack://ReactJsonTree/./src/JSONObjectNode.js?");

/***/ }),

/***/ "./src/JSONValueNode.js":
/*!******************************!*\
  !*** ./src/JSONValueNode.js ***!
  \******************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ \"react\");\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ \"../../node_modules/prop-types/index.js\");\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);\nfunction _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }\n\nfunction _nonIterableSpread() { throw new TypeError(\"Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }\n\n\n\n/**\n * Renders simple values (eg. strings, numbers, booleans, etc)\n */\n\nvar JSONValueNode = function JSONValueNode(_ref) {\n  var nodeType = _ref.nodeType,\n      styling = _ref.styling,\n      labelRenderer = _ref.labelRenderer,\n      keyPath = _ref.keyPath,\n      valueRenderer = _ref.valueRenderer,\n      value = _ref.value,\n      valueGetter = _ref.valueGetter;\n  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"li\", styling('value', nodeType, keyPath), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"label\", styling(['label', 'valueLabel'], nodeType, keyPath), labelRenderer(keyPath, nodeType, false, false)), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"span\", styling('valueText', nodeType, keyPath), valueRenderer.apply(void 0, [valueGetter(value), value].concat(_toConsumableArray(keyPath)))));\n};\n\nJSONValueNode.propTypes = {\n  nodeType: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string.isRequired,\n  styling: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  labelRenderer: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  keyPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.arrayOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])).isRequired,\n  valueRenderer: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func.isRequired,\n  value: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.any,\n  valueGetter: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func\n};\nJSONValueNode.defaultProps = {\n  valueGetter: function valueGetter(value) {\n    return value;\n  }\n};\n/* harmony default export */ __webpack_exports__[\"default\"] = (JSONValueNode);\n\n//# sourceURL=webpack://ReactJsonTree/./src/JSONValueNode.js?");

/***/ }),

/***/ "./src/createStylingFromTheme.js":
/*!***************************************!*\
  !*** ./src/createStylingFromTheme.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var react_base16_styling__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react-base16-styling */ \"../react-base16-styling/lib/index.js\");\n/* harmony import */ var react_base16_styling__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react_base16_styling__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var _themes_solarized__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./themes/solarized */ \"./src/themes/solarized.js\");\nfunction ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }\n\nfunction _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }\n\nfunction _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }\n\n\n\n\nvar colorMap = function colorMap(theme) {\n  return {\n    BACKGROUND_COLOR: theme.base00,\n    TEXT_COLOR: theme.base07,\n    STRING_COLOR: theme.base0B,\n    DATE_COLOR: theme.base0B,\n    NUMBER_COLOR: theme.base09,\n    BOOLEAN_COLOR: theme.base09,\n    NULL_COLOR: theme.base08,\n    UNDEFINED_COLOR: theme.base08,\n    FUNCTION_COLOR: theme.base08,\n    SYMBOL_COLOR: theme.base08,\n    LABEL_COLOR: theme.base0D,\n    ARROW_COLOR: theme.base0D,\n    ITEM_STRING_COLOR: theme.base0B,\n    ITEM_STRING_EXPANDED_COLOR: theme.base03\n  };\n};\n\nvar valueColorMap = function valueColorMap(colors) {\n  return {\n    String: colors.STRING_COLOR,\n    Date: colors.DATE_COLOR,\n    Number: colors.NUMBER_COLOR,\n    Boolean: colors.BOOLEAN_COLOR,\n    Null: colors.NULL_COLOR,\n    Undefined: colors.UNDEFINED_COLOR,\n    Function: colors.FUNCTION_COLOR,\n    Symbol: colors.SYMBOL_COLOR\n  };\n};\n\nvar getDefaultThemeStyling = function getDefaultThemeStyling(theme) {\n  var colors = colorMap(theme);\n  return {\n    tree: {\n      border: 0,\n      padding: 0,\n      marginTop: '0.5em',\n      marginBottom: '0.5em',\n      marginLeft: '0.125em',\n      marginRight: 0,\n      listStyle: 'none',\n      MozUserSelect: 'none',\n      WebkitUserSelect: 'none',\n      backgroundColor: colors.BACKGROUND_COLOR\n    },\n    value: function value(_ref, nodeType, keyPath) {\n      var style = _ref.style;\n      return {\n        style: _objectSpread(_objectSpread({}, style), {}, {\n          paddingTop: '0.25em',\n          paddingRight: 0,\n          marginLeft: '0.875em',\n          WebkitUserSelect: 'text',\n          MozUserSelect: 'text',\n          wordWrap: 'break-word',\n          paddingLeft: keyPath.length > 1 ? '2.125em' : '1.25em',\n          textIndent: '-0.5em',\n          wordBreak: 'break-all'\n        })\n      };\n    },\n    label: {\n      display: 'inline-block',\n      color: colors.LABEL_COLOR\n    },\n    valueLabel: {\n      margin: '0 0.5em 0 0'\n    },\n    valueText: function valueText(_ref2, nodeType) {\n      var style = _ref2.style;\n      return {\n        style: _objectSpread(_objectSpread({}, style), {}, {\n          color: valueColorMap(colors)[nodeType]\n        })\n      };\n    },\n    itemRange: function itemRange(styling, expanded) {\n      return {\n        style: {\n          paddingTop: expanded ? 0 : '0.25em',\n          cursor: 'pointer',\n          color: colors.LABEL_COLOR\n        }\n      };\n    },\n    arrow: function arrow(_ref3, nodeType, expanded) {\n      var style = _ref3.style;\n      return {\n        style: _objectSpread(_objectSpread({}, style), {}, {\n          marginLeft: 0,\n          transition: '150ms',\n          WebkitTransition: '150ms',\n          MozTransition: '150ms',\n          WebkitTransform: expanded ? 'rotateZ(90deg)' : 'rotateZ(0deg)',\n          MozTransform: expanded ? 'rotateZ(90deg)' : 'rotateZ(0deg)',\n          transform: expanded ? 'rotateZ(90deg)' : 'rotateZ(0deg)',\n          transformOrigin: '45% 50%',\n          WebkitTransformOrigin: '45% 50%',\n          MozTransformOrigin: '45% 50%',\n          position: 'relative',\n          lineHeight: '1.1em',\n          fontSize: '0.75em'\n        })\n      };\n    },\n    arrowContainer: function arrowContainer(_ref4, arrowStyle) {\n      var style = _ref4.style;\n      return {\n        style: _objectSpread(_objectSpread({}, style), {}, {\n          display: 'inline-block',\n          paddingRight: '0.5em',\n          paddingLeft: arrowStyle === 'double' ? '1em' : 0,\n          cursor: 'pointer'\n        })\n      };\n    },\n    arrowSign: {\n      color: colors.ARROW_COLOR\n    },\n    arrowSignInner: {\n      position: 'absolute',\n      top: 0,\n      left: '-0.4em'\n    },\n    nestedNode: function nestedNode(_ref5, keyPath, nodeType, expanded, expandable) {\n      var style = _ref5.style;\n      return {\n        style: _objectSpread(_objectSpread({}, style), {}, {\n          position: 'relative',\n          paddingTop: '0.25em',\n          marginLeft: keyPath.length > 1 ? '0.875em' : 0,\n          paddingLeft: !expandable ? '1.125em' : 0\n        })\n      };\n    },\n    rootNode: {\n      padding: 0,\n      margin: 0\n    },\n    nestedNodeLabel: function nestedNodeLabel(_ref6, keyPath, nodeType, expanded, expandable) {\n      var style = _ref6.style;\n      return {\n        style: _objectSpread(_objectSpread({}, style), {}, {\n          margin: 0,\n          padding: 0,\n          WebkitUserSelect: expandable ? 'inherit' : 'text',\n          MozUserSelect: expandable ? 'inherit' : 'text',\n          cursor: expandable ? 'pointer' : 'default'\n        })\n      };\n    },\n    nestedNodeItemString: function nestedNodeItemString(_ref7, keyPath, nodeType, expanded) {\n      var style = _ref7.style;\n      return {\n        style: _objectSpread(_objectSpread({}, style), {}, {\n          paddingLeft: '0.5em',\n          cursor: 'default',\n          color: expanded ? colors.ITEM_STRING_EXPANDED_COLOR : colors.ITEM_STRING_COLOR\n        })\n      };\n    },\n    nestedNodeItemType: {\n      marginLeft: '0.3em',\n      marginRight: '0.3em'\n    },\n    nestedNodeChildren: function nestedNodeChildren(_ref8, nodeType, expanded) {\n      var style = _ref8.style;\n      return {\n        style: _objectSpread(_objectSpread({}, style), {}, {\n          padding: 0,\n          margin: 0,\n          listStyle: 'none',\n          display: expanded ? 'block' : 'none'\n        })\n      };\n    },\n    rootNodeChildren: {\n      padding: 0,\n      margin: 0,\n      listStyle: 'none'\n    }\n  };\n};\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (Object(react_base16_styling__WEBPACK_IMPORTED_MODULE_0__[\"createStyling\"])(getDefaultThemeStyling, {\n  defaultBase16: _themes_solarized__WEBPACK_IMPORTED_MODULE_1__[\"default\"]\n}));\n\n//# sourceURL=webpack://ReactJsonTree/./src/createStylingFromTheme.js?");

/***/ }),

/***/ "./src/getCollectionEntries.js":
/*!*************************************!*\
  !*** ./src/getCollectionEntries.js ***!
  \*************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"default\", function() { return getCollectionEntries; });\nfunction _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }\n\nfunction _nonIterableSpread() { throw new TypeError(\"Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _iterableToArray(iter) { if (typeof Symbol !== \"undefined\" && Symbol.iterator in Object(iter)) return Array.from(iter); }\n\nfunction _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }\n\nfunction _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === \"undefined\" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === \"number\") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError(\"Invalid attempt to iterate non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it[\"return\"] != null) it[\"return\"](); } finally { if (didErr) throw err; } } }; }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }\n\nfunction getLength(type, collection) {\n  if (type === 'Object') {\n    return Object.keys(collection).length;\n  } else if (type === 'Array') {\n    return collection.length;\n  }\n\n  return Infinity;\n}\n\nfunction isIterableMap(collection) {\n  return typeof collection.set === 'function';\n}\n\nfunction getEntries(type, collection, sortObjectKeys) {\n  var from = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;\n  var to = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : Infinity;\n  var res;\n\n  if (type === 'Object') {\n    var keys = Object.getOwnPropertyNames(collection);\n\n    if (sortObjectKeys) {\n      keys.sort(sortObjectKeys === true ? undefined : sortObjectKeys);\n    }\n\n    keys = keys.slice(from, to + 1);\n    res = {\n      entries: keys.map(function (key) {\n        return {\n          key: key,\n          value: collection[key]\n        };\n      })\n    };\n  } else if (type === 'Array') {\n    res = {\n      entries: collection.slice(from, to + 1).map(function (val, idx) {\n        return {\n          key: idx + from,\n          value: val\n        };\n      })\n    };\n  } else {\n    var idx = 0;\n    var entries = [];\n    var done = true;\n    var isMap = isIterableMap(collection);\n\n    var _iterator = _createForOfIteratorHelper(collection),\n        _step;\n\n    try {\n      for (_iterator.s(); !(_step = _iterator.n()).done;) {\n        var item = _step.value;\n\n        if (idx > to) {\n          done = false;\n          break;\n        }\n\n        if (from <= idx) {\n          if (isMap && Array.isArray(item)) {\n            if (typeof item[0] === 'string' || typeof item[0] === 'number') {\n              entries.push({\n                key: item[0],\n                value: item[1]\n              });\n            } else {\n              entries.push({\n                key: \"[entry \".concat(idx, \"]\"),\n                value: {\n                  '[key]': item[0],\n                  '[value]': item[1]\n                }\n              });\n            }\n          } else {\n            entries.push({\n              key: idx,\n              value: item\n            });\n          }\n        }\n\n        idx++;\n      }\n    } catch (err) {\n      _iterator.e(err);\n    } finally {\n      _iterator.f();\n    }\n\n    res = {\n      hasMore: !done,\n      entries: entries\n    };\n  }\n\n  return res;\n}\n\nfunction getRanges(from, to, limit) {\n  var ranges = [];\n\n  while (to - from > limit * limit) {\n    limit = limit * limit;\n  }\n\n  for (var i = from; i <= to; i += limit) {\n    ranges.push({\n      from: i,\n      to: Math.min(to, i + limit - 1)\n    });\n  }\n\n  return ranges;\n}\n\nfunction getCollectionEntries(type, collection, sortObjectKeys, limit) {\n  var from = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 0;\n  var to = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : Infinity;\n  var getEntriesBound = getEntries.bind(null, type, collection, sortObjectKeys);\n\n  if (!limit) {\n    return getEntriesBound().entries;\n  }\n\n  var isSubset = to < Infinity;\n  var length = Math.min(to - from, getLength(type, collection));\n\n  if (type !== 'Iterable') {\n    if (length <= limit || limit < 7) {\n      return getEntriesBound(from, to).entries;\n    }\n  } else {\n    if (length <= limit && !isSubset) {\n      return getEntriesBound(from, to).entries;\n    }\n  }\n\n  var limitedEntries;\n\n  if (type === 'Iterable') {\n    var _getEntriesBound = getEntriesBound(from, from + limit - 1),\n        hasMore = _getEntriesBound.hasMore,\n        entries = _getEntriesBound.entries;\n\n    limitedEntries = hasMore ? [].concat(_toConsumableArray(entries), _toConsumableArray(getRanges(from + limit, from + 2 * limit - 1, limit))) : entries;\n  } else {\n    limitedEntries = isSubset ? getRanges(from, to, limit) : [].concat(_toConsumableArray(getEntriesBound(0, limit - 5).entries), _toConsumableArray(getRanges(limit - 4, length - 5, limit)), _toConsumableArray(getEntriesBound(length - 4, length - 1).entries));\n  }\n\n  return limitedEntries;\n}\n\n//# sourceURL=webpack://ReactJsonTree/./src/getCollectionEntries.js?");

/***/ }),

/***/ "./src/index.js":
/*!**********************!*\
  !*** ./src/index.js ***!
  \**********************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"default\", function() { return JSONTree; });\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ \"react\");\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ \"../../node_modules/prop-types/index.js\");\n/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var _JSONNode__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./JSONNode */ \"./src/JSONNode.js\");\n/* harmony import */ var _createStylingFromTheme__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./createStylingFromTheme */ \"./src/createStylingFromTheme.js\");\n/* harmony import */ var react_base16_styling__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! react-base16-styling */ \"../react-base16-styling/lib/index.js\");\n/* harmony import */ var react_base16_styling__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react_base16_styling__WEBPACK_IMPORTED_MODULE_4__);\nfunction _typeof(obj) { \"@babel/helpers - typeof\"; if (typeof Symbol === \"function\" && typeof Symbol.iterator === \"symbol\") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === \"function\" && obj.constructor === Symbol && obj !== Symbol.prototype ? \"symbol\" : typeof obj; }; } return _typeof(obj); }\n\nfunction _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }\n\nfunction _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }\n\nfunction _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n\nfunction _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function\"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }\n\nfunction _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }\n\nfunction _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }\n\nfunction _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === \"object\" || typeof call === \"function\")) { return call; } return _assertThisInitialized(self); }\n\nfunction _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return self; }\n\nfunction _isNativeReflectConstruct() { if (typeof Reflect === \"undefined\" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === \"function\") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }\n\nfunction _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }\n\nfunction ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }\n\nfunction _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }\n\nfunction _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }\n\nfunction _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }\n\nfunction _nonIterableRest() { throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\"); }\n\nfunction _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === \"string\") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === \"Object\" && o.constructor) n = o.constructor.name; if (n === \"Map\" || n === \"Set\") return Array.from(o); if (n === \"Arguments\" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }\n\nfunction _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }\n\nfunction _iterableToArrayLimit(arr, i) { if (typeof Symbol === \"undefined\" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i[\"return\"] != null) _i[\"return\"](); } finally { if (_d) throw _e; } } return _arr; }\n\nfunction _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }\n\n// ES6 + inline style port of JSONViewer https://bitbucket.org/davevedder/react-json-viewer/\n// all credits and original code to the author\n// Dave Vedder <veddermatic@gmail.com> http://www.eskimospy.com/\n// port by Daniele Zannotti http://www.github.com/dzannotti <dzannotti@me.com>\n\n\n\n\n\n\nvar identity = function identity(value) {\n  return value;\n};\n\nvar expandRootNode = function expandRootNode(keyName, data, level) {\n  return level === 0;\n};\n\nvar defaultItemString = function defaultItemString(type, data, itemType, itemString) {\n  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"span\", null, itemType, \" \", itemString);\n};\n\nvar defaultLabelRenderer = function defaultLabelRenderer(_ref) {\n  var _ref2 = _slicedToArray(_ref, 1),\n      label = _ref2[0];\n\n  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"span\", null, label, \":\");\n};\n\nvar noCustomNode = function noCustomNode() {\n  return false;\n};\n\nfunction checkLegacyTheming(theme, props) {\n  var deprecatedStylingMethodsMap = {\n    getArrowStyle: 'arrow',\n    getListStyle: 'nestedNodeChildren',\n    getItemStringStyle: 'nestedNodeItemString',\n    getLabelStyle: 'label',\n    getValueStyle: 'valueText'\n  };\n  var deprecatedStylingMethods = Object.keys(deprecatedStylingMethodsMap).filter(function (name) {\n    return props[name];\n  });\n\n  if (deprecatedStylingMethods.length > 0) {\n    if (typeof theme === 'string') {\n      theme = {\n        extend: theme\n      };\n    } else {\n      theme = _objectSpread({}, theme);\n    }\n\n    deprecatedStylingMethods.forEach(function (name) {\n      // eslint-disable-next-line no-console\n      console.error(\"Styling method \\\"\".concat(name, \"\\\" is deprecated, use \\\"theme\\\" property instead\"));\n\n      theme[deprecatedStylingMethodsMap[name]] = function (_ref3) {\n        var style = _ref3.style;\n\n        for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {\n          args[_key - 1] = arguments[_key];\n        }\n\n        return {\n          style: _objectSpread(_objectSpread({}, style), props[name].apply(props, args))\n        };\n      };\n    });\n  }\n\n  return theme;\n}\n\nfunction getStateFromProps(props) {\n  var theme = checkLegacyTheming(props.theme, props);\n\n  if (props.invertTheme) {\n    theme = Object(react_base16_styling__WEBPACK_IMPORTED_MODULE_4__[\"invertTheme\"])(theme);\n  }\n\n  return {\n    styling: Object(_createStylingFromTheme__WEBPACK_IMPORTED_MODULE_3__[\"default\"])(theme)\n  };\n}\n\nvar JSONTree = /*#__PURE__*/function (_React$Component) {\n  _inherits(JSONTree, _React$Component);\n\n  var _super = _createSuper(JSONTree);\n\n  function JSONTree(props) {\n    var _this;\n\n    _classCallCheck(this, JSONTree);\n\n    _this = _super.call(this, props);\n    _this.state = getStateFromProps(props);\n    return _this;\n  }\n\n  _createClass(JSONTree, [{\n    key: \"UNSAFE_componentWillReceiveProps\",\n    value: function UNSAFE_componentWillReceiveProps(nextProps) {\n      var _this2 = this;\n\n      if (['theme', 'invertTheme'].find(function (k) {\n        return nextProps[k] !== _this2.props[k];\n      })) {\n        this.setState(getStateFromProps(nextProps));\n      }\n    }\n  }, {\n    key: \"shouldComponentUpdate\",\n    value: function shouldComponentUpdate(nextProps) {\n      var _this3 = this;\n\n      return !!Object.keys(nextProps).find(function (k) {\n        return k === 'keyPath' ? nextProps[k].join('/') !== _this3.props[k].join('/') : nextProps[k] !== _this3.props[k];\n      });\n    }\n  }, {\n    key: \"render\",\n    value: function render() {\n      var _this$props = this.props,\n          value = _this$props.data,\n          keyPath = _this$props.keyPath,\n          postprocessValue = _this$props.postprocessValue,\n          hideRoot = _this$props.hideRoot,\n          theme = _this$props.theme,\n          _ = _this$props.invertTheme,\n          rest = _objectWithoutProperties(_this$props, [\"data\", \"keyPath\", \"postprocessValue\", \"hideRoot\", \"theme\", \"invertTheme\"]);\n\n      var styling = this.state.styling;\n      return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(\"ul\", styling('tree'), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement(_JSONNode__WEBPACK_IMPORTED_MODULE_2__[\"default\"], _extends({}, _objectSpread({\n        postprocessValue: postprocessValue,\n        hideRoot: hideRoot,\n        styling: styling\n      }, rest), {\n        keyPath: hideRoot ? [] : keyPath,\n        value: postprocessValue(value)\n      })));\n    }\n  }]);\n\n  return JSONTree;\n}(react__WEBPACK_IMPORTED_MODULE_0___default.a.Component);\n\n_defineProperty(JSONTree, \"propTypes\", {\n  data: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.any.isRequired,\n  hideRoot: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,\n  theme: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.object, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string]),\n  invertTheme: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,\n  keyPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.arrayOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),\n  postprocessValue: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func,\n  sortObjectKeys: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool])\n});\n\n_defineProperty(JSONTree, \"defaultProps\", {\n  shouldExpandNode: expandRootNode,\n  hideRoot: false,\n  keyPath: ['root'],\n  getItemString: defaultItemString,\n  labelRenderer: defaultLabelRenderer,\n  valueRenderer: identity,\n  postprocessValue: identity,\n  isCustomNode: noCustomNode,\n  collectionLimit: 50,\n  invertTheme: true\n});\n\n\n\n//# sourceURL=webpack://ReactJsonTree/./src/index.js?");

/***/ }),

/***/ "./src/objType.js":
/*!************************!*\
  !*** ./src/objType.js ***!
  \************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"default\", function() { return objType; });\nfunction objType(obj) {\n  var type = Object.prototype.toString.call(obj).slice(8, -1);\n\n  if (type === 'Object' && typeof obj[Symbol.iterator] === 'function') {\n    return 'Iterable';\n  }\n\n  if (type === 'Custom' && obj.constructor !== Object && obj instanceof Object) {\n    // For projects implementing objects overriding `.prototype[Symbol.toStringTag]`\n    return 'Object';\n  }\n\n  return type;\n}\n\n//# sourceURL=webpack://ReactJsonTree/./src/objType.js?");

/***/ }),

/***/ "./src/themes/solarized.js":
/*!*********************************!*\
  !*** ./src/themes/solarized.js ***!
  \*********************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony default export */ __webpack_exports__[\"default\"] = ({\n  scheme: 'solarized',\n  author: 'ethan schoonover (http://ethanschoonover.com/solarized)',\n  base00: '#002b36',\n  base01: '#073642',\n  base02: '#586e75',\n  base03: '#657b83',\n  base04: '#839496',\n  base05: '#93a1a1',\n  base06: '#eee8d5',\n  base07: '#fdf6e3',\n  base08: '#dc322f',\n  base09: '#cb4b16',\n  base0A: '#b58900',\n  base0B: '#859900',\n  base0C: '#2aa198',\n  base0D: '#268bd2',\n  base0E: '#6c71c4',\n  base0F: '#d33682'\n});\n\n//# sourceURL=webpack://ReactJsonTree/./src/themes/solarized.js?");

/***/ }),

/***/ 0:
/*!****************************!*\
  !*** multi ./src/index.js ***!
  \****************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("module.exports = __webpack_require__(/*! ./src/index.js */\"./src/index.js\");\n\n\n//# sourceURL=webpack://ReactJsonTree/multi_./src/index.js?");

/***/ }),

/***/ "react":
/*!**************************************************************************************!*\
  !*** external {"root":"React","commonjs2":"react","commonjs":"react","amd":"react"} ***!
  \**************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports) {

eval("module.exports = __WEBPACK_EXTERNAL_MODULE_react__;\n\n//# sourceURL=webpack://ReactJsonTree/external_%7B%22root%22:%22React%22,%22commonjs2%22:%22react%22,%22commonjs%22:%22react%22,%22amd%22:%22react%22%7D?");

/***/ })

/******/ })["default"];
});